#!/usr/bin/python
#
# Copyright (c) 2024 xuzhang3 (@xuzhang3), Fred-sun (@Fred-sun)
#
# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

from __future__ import absolute_import, division, print_function
__metaclass__ = type

DOCUMENTATION = '''
---
module: azure_rm_batchaccountpool_info
version_added: "3.0.0"
short_description: Get the Batch Account Pool facts
description:
    - Get the Batch Account Pool facts.

options:
    resource_group:
        description:
            - The name of the resource group in which to create the Batch Account.
        type: str
        required: true
    batch_account_name:
        description:
            - The name of the Batch Account.
        type: str
        required: true
    name:
        description:
            - The name of the batch account pool.
        type: str

extends_documentation_fragment:
    - azure.azcollection.azure

author:
    - xuzhang3 (@xuzhang3)
    - Fred Sun (@Fred-sun)
'''

EXAMPLES = '''
- name: Get the Batch Account Pool by name
  azure_rm_batchaccountpool_info:
    resource_group: MyResGroup
    batch_account_name: batchname01
    name: mypool01

- name: List the Batch Account Pool
  azure_rm_batchaccountpool_info:
    resource_group: MyResGroup
    batch_account_name: batchname01
'''

RETURN = '''
batch_account_pool:
    description:
        - Contains information about an pool in a Batch account.
    type: dict
    returned: always
    sample: {
                "allocation_state": "Steady",
                "allocation_state_transition_time": "2024-11-05T08:58:16.803138Z",
                "batch_account_name": "fredbatch02",
                "creation_time": "2024-11-05T08:58:15.399345Z",
                "current_dedicated_nodes": 0,
                "current_low_priority_nodes": 0,
                "deployment_configuration": {
                    "virtual_machine_configuration": {
                        "image_reference": {
                            "offer": "ubuntu-hpc",
                            "publisher": "microsoft-dsvm",
                            "sku": "2204",
                            "version": "latest"
                        },
                        "node_agent_sku_id": "batch.node.ubuntu 22.04",
                        "node_placement_configuration": {
                            "policy": "Regional"
                        },
                        "os_disk": {
                            "caching": "None",
                            "managed_disk": {
                                "storage_account_type": "Premium_LRS"
                            }
                        }
                    }
                },
                "etag": "0x8DCFD77FC345CFE",
                "id": "/subscriptions/xxx-xxx/resourceGroups/testRG/providers/Microsoft.Batch/batchAccounts/batch01/pools/pool01",
                "inter_node_communication": "Disabled",
                "last_modified": "2024-11-05T08:58:15.399347Z",
                "name": "poolfredbatch02--002",
                "network_configuration": {
                    "dynamic_vnet_assignment_scope": "None",
                    "enable_accelerated_networking": false,
                    "endpoint_configuration": {
                        "inbound_nat_pools": [
                            {
                                "backend_port": 33,
                                "frontend_port_range_end": 49999,
                                "frontend_port_range_start": 1,
                                "name": "nat02",
                                "protocol": "UDP"
                            }
                        ]
                    },
                    "public_ip_address_configuration": {
                        "provision": "BatchManaged"
                    },
                    "subnet_id": "/subscriptions/xxx-xxx/resourceGroups/testrg/providers/Microsoft.Network/virtualNetworks/vnet01/subnets/default"
                },
                "provisioning_state": "Succeeded",
                "provisioning_state_transition_time": "2024-11-05T08:58:15.399345Z",
                "resize_operation_status": {
                    "node_deallocation_option": "Requeue",
                    "resize_timeout": "PT15M",
                    "start_time": "2024-11-05T08:58:15.399317Z",
                    "target_dedicated_nodes": 0
                },
                "resource_group": "v-xisuRG06",
                "scale_settings": {
                    "fixed_scale": {
                        "resize_timeout": "PT15M",
                        "target_dedicated_nodes": 0,
                        "target_low_priority_nodes": 0
                    }
                },
                "target_node_communication_mode": "Default",
                "task_scheduling_policy": {
                    "node_fill_type": "Pack"
                },
                "task_slots_per_node": 1,
                "type": "Microsoft.Batch/batchAccounts/pools",
                "upgrade_policy": {
                    "automatic_os_upgrade_policy": {
                        "disable_automatic_rollback": false,
                        "enable_automatic_os_upgrade": false,
                        "os_rolling_upgrade_deferral": false,
                        "use_rolling_upgrade_policy": false
                    },
                    "mode": "Manual",
                    "rolling_upgrade_policy": {
                        "max_batch_instance_percent": 20,
                        "max_unhealthy_instance_percent": 20,
                        "max_unhealthy_upgraded_instance_percent": 20,
                        "pause_time_between_batches": "P0D",
                        "rollback_failed_instances_on_policy_breach": false
                    }
                },
                "vm_size": "STANDARD_D2S_V3"
            }
'''

from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common_ext import AzureRMModuleBase

try:
    from azure.core.exceptions import ResourceNotFoundError
except ImportError:
    # This is handled in azure_rm_common
    pass


class AzureRMBatchAccountPoolInfo(AzureRMModuleBase):
    """Configuration class for an Azure RM Batch Account Pool package resource"""

    def __init__(self):
        self.module_arg_spec = dict(
            resource_group=dict(
                type='str',
                required=True,
            ),
            batch_account_name=dict(
                type='str',
                required=True
            ),
            name=dict(
                type='str',
            ),
        )

        self.resource_group = None
        self.batch_account_name = None
        self.name = None

        self.results = dict(changed=False)

        super(AzureRMBatchAccountPoolInfo, self).__init__(derived_arg_spec=self.module_arg_spec,
                                                          supports_check_mode=True,
                                                          supports_tags=False)

    def exec_module(self, **kwargs):
        """Main module execution method"""

        for key in list(self.module_arg_spec.keys()):
            setattr(self, key, kwargs[key])

        response = []

        if self.name is not None:
            response = [self.get_batchaccount_pool()]
        else:
            response = self.list_by_batchaccount_pool()

        self.results['batch_account_pool'] = [self.format_item(item) for item in response]

        return self.results

    def list_by_batchaccount_pool(self):
        self.log("List all Batch Account in the batch account {0}".format(self.batch_account_name))
        result = []
        response = []
        try:
            response = self.batch_account_client.pool.list_by_batch_account(resource_group_name=self.resource_group,
                                                                            account_name=self.batch_account_name)
            self.log("Response : {0}".format(response))
        except Exception as e:
            self.log('Did not find the Batch Account instance. Exception as {0}'.format(e))
        for item in response:
            result.append(item.as_dict())
        return result

    def get_batchaccount_pool(self):
        '''
        Gets the properties of the specified Batch Account Pool
        '''
        self.log("Fetch the Batch Account instance {0} is present".format(self.name))
        try:
            response = self.batch_account_client.pool.get(resource_group_name=self.resource_group,
                                                          account_name=self.batch_account_name,
                                                          pool_name=self.name)
            self.log("Response : {0}".format(response))
        except ResourceNotFoundError:
            self.log('Did not find the Batch Account Pool instance.')
            return
        return response.as_dict()

    def format_item(self, item):
        if item is None:
            return
        result = item
        result['resource_group'] = self.resource_group
        result['batch_account_name'] = self.batch_account_name
        return result


def main():
    """Main execution"""
    AzureRMBatchAccountPoolInfo()


if __name__ == '__main__':
    main()



# -*- coding: utf-8 -*-
# Copyright 2021 Red Hat
# GNU General Public License v3.0+
# (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

from __future__ import absolute_import, division, print_function


__metaclass__ = type

"""
The iosxr prefix_lists fact class
It is in this file the configuration is collected from the device
for a given resource, parsed, and the facts tree is populated
based on the configuration.
"""


from ansible_collections.ansible.netcommon.plugins.module_utils.network.common import utils

from ansible_collections.cisco.iosxr.plugins.module_utils.network.iosxr.argspec.prefix_lists.prefix_lists import (
    Prefix_listsArgs,
)
from ansible_collections.cisco.iosxr.plugins.module_utils.network.iosxr.rm_templates.prefix_lists import (
    Prefix_listsTemplate,
)


class Prefix_listsFacts(object):
    """The iosxr prefix_lists facts class"""

    def __init__(self, module, subspec="config", options="options"):
        self._module = module
        self.argument_spec = Prefix_listsArgs.argument_spec

    def get_config(self, connection):
        return connection.get("show running-config")

    def populate_facts(self, connection, ansible_facts, data=None):
        """Populate the facts for Prefix_lists network resource

        :param connection: the device connection
        :param ansible_facts: Facts dictionary
        :param data: previously collected conf

        :rtype: dictionary
        :returns: facts
        """
        facts = {}
        objs = []
        if not data:
            data = self.get_config(connection)

        # parse native config using the Prefix_lists template
        prefix_lists_parser = Prefix_listsTemplate(
            lines=data.splitlines(),
            module=self._module,
        )
        objs = list(prefix_lists_parser.parse().values())

        if objs:
            for item in objs:
                item["prefix_lists"] = list(item["prefix_lists"].values())

        ansible_facts["ansible_network_resources"].pop("prefix_lists", None)

        params = utils.remove_empties(
            prefix_lists_parser.validate_config(
                self.argument_spec,
                {"config": objs},
                redact=True,
            ),
        )

        facts["prefix_lists"] = params.get("config", [])
        ansible_facts["ansible_network_resources"].update(facts)

        return ansible_facts



#!/usr/bin/python
#
# Copyright (c) 2020 Fred-Sun, (@Fred-Sun)
#
# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

from __future__ import absolute_import, division, print_function
__metaclass__ = type


DOCUMENTATION = '''
---
module: azure_rm_vpnsite_info
version_added: '1.5.0'
short_description: Get VpnSite info
description:
    - Get info of VpnSite.
options:
    resource_group:
        description:
            - The resource group name of the VpnSite.
        type: str
    name:
        description:
            - The name of the VpnSite being retrieved.
        type: str
extends_documentation_fragment:
    - azure.azcollection.azure
    - azure.azcollection.azure_tags
author:
    - Fred-Sun (@Fred-Sun)

'''

EXAMPLES = '''
- name: Get Vpn Site Info by name
  azure_rm_vpnsite_info:
    resource_group: myResourceGroup
    name: vwan_site_name

- name: Get Vpn Site List By ResourceGroup
  azure_rm_vpnsite_info:
    resource_group: myResourceGroup

- name: Get Vpn Site List By Subscription
  azure_rm_vpnsite_info:
'''

RETURN = '''
vpn_sites:
    description:
        - A list of dict results where the key is the name of the VpnSite and the values are the facts for that VpnSite.
    returned: always
    type: complex
    contains:
        id:
            description:
               - Resource ID.
            returned: always
            type: str
            sample: /subscriptions/xxx-xxx/resourceGroups/myResourceGroup/providers/Microsoft.Network/vpnSites/vwam_site_name
        name:
            description:
                - Resource name.
            returned: always
            type: str
            sample: vwan_site_name
        type:
            description:
                - Resource type.
            returned: always
            type: str
            sample: Microsoft.Network/vpnSites
        location:
            description:
                - Resource location.
            returned: always
            type: str
            sample: eastus
        tags:
            description:
                - Resource tags.
            returned: always
            type: dict
            sample: { "key1":"value1"}
        etag:
            description:
                - A unique read-only string that changes whenever the resource is updated.
            returned: always
            type: str
            sample: 1d8c0731-adc6-4022-9c70-3c389cd73e2a
        virtual_wan:
            description:
                - The VirtualWAN to which the vpnSite belongs.
            returned: always
            type: dict
            sample: {"id": "/subscriptions/xxx-xxx/resourceGroups/myResourceGroup/providers/Microsoft.Network/virtualWans/vwan_name"}
        device_properties:
            description:
                - The device properties.
            returned: always
            type: dict
            sample: {"device_vendor": "myVM", "link_speed_in_mbps": 0}
        address_space:
            description:
                - The AddressSpace that contains an array of IP address ranges.
            returned: always
            type: dict
            sample: {"address_prefixes": ["10.0.0.0/24",]}
        provisioning_state:
            description:
                - The provisioning state of the VPN site resource.
            returned: always
            type: str
            sample: "succeeded"
        is_security_site:
            description:
                - IsSecuritySite flag.
            returned: always
            type: bool
            sample: false
        vpn_site_links:
            description:
                - List of all vpn site links.
            returned: always
            type: complex
            contains:
                name:
                    description:
                         - The name of the resource that is unique within a resource group.
                         - This name can be used to access the resource.
                    returned: always
                    type: str
                    sample: azureuser
                link_properties:
                    description:
                        - The link provider properties.
                    returned: always
                    type: dict
                    sample: {"link_provider_name": "azureuser", "link_speed_in_mbps": 100}
                ip_address:
                    description:
                        - The ip-address for the vpn-site-link.
                    returned: always
                    type: str
                    sample: 192.168.33.223
                etag:
                    description:
                        - A unique read-only string that changes whenever the resource is updated.
                    returned: always
                    type: str
                    sample: 1d8c0731-adc6-4022-9c70-3c389cd73e2a
                id:
                    description:
                       - Resource ID.
                    returned: always
                    type: str
                    sample: /subscriptions/xxx-xxx/resourceGroups/myResourceGroup/providers/Microsoft.Network/vpnSites/vwam_site_name
                type:
                    description:
                        - Resource type.
                    returned: always
                    type: str
                    sample: Microsoft.Network/vpnSites
        o365_policy:
            description:
                - Office365 Policy.
            returned: always
            type: dict
            sample: {"break_out_categories": {"allow": false,"default": false,"optimize": false}}

'''

from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common_ext import AzureRMModuleBase
try:
    from azure.core.exceptions import ResourceNotFoundError
except ImportError:
    # This is handled in azure_rm_common
    pass


class AzureRMVpnSiteInfo(AzureRMModuleBase):
    def __init__(self):
        self.module_arg_spec = dict(
            resource_group=dict(
                type='str'
            ),
            name=dict(
                type='str'
            )
        )

        self.resource_group = None
        self.name = None

        self.results = dict(changed=False)

        super(AzureRMVpnSiteInfo, self).__init__(self.module_arg_spec, supports_check_mode=True, supports_tags=True)

    def exec_module(self, **kwargs):

        for key in self.module_arg_spec:
            setattr(self, key, kwargs[key])

        if (self.resource_group is not None and self.name is not None):
            self.results['vpn_sites'] = self.format_item(self.get())
        elif (self.resource_group is not None):
            self.results['vpn_sites'] = self.format_item(self.list_by_resource_group())
        else:
            self.results['vpn_sites'] = self.format_item(self.list())
        return self.results

    def get(self):
        response = None

        try:
            response = self.network_client.vpn_sites.get(resource_group_name=self.resource_group,
                                                         vpn_site_name=self.name)
        except ResourceNotFoundError as e:
            self.log('Could not get info for @(Model.ModuleOperationNameUpper).')

        return response

    def list_by_resource_group(self):
        response = None

        try:
            response = self.network_client.vpn_sites.list_by_resource_group(resource_group_name=self.resource_group)
        except ResourceNotFoundError as e:
            self.log('Could not get info for @(Model.ModuleOperationNameUpper).')

        return response

    def list(self):
        response = None

        try:
            response = self.network_client.vpn_sites.list()
        except ResourceNotFoundError as e:
            self.log('Could not get info for @(Model.ModuleOperationNameUpper).')

        return response

    def format_item(self, item):
        if hasattr(item, 'as_dict'):
            return [item.as_dict()]
        elif item is not None:
            result = []
            items = list(item)
            for tmp in items:
                result.append(tmp.as_dict())
            return result
        else:
            return None


def main():
    AzureRMVpnSiteInfo()


if __name__ == '__main__':
    main()



#!/usr/bin/python
# -*- coding: utf-8 -*-
# Copyright 2019 Red Hat
# GNU General Public License v3.0+
# (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

#############################################
#                WARNING                    #
#############################################
#
# This file is auto generated by the resource
#   module builder playbook.
#
# Do not edit this file manually.
#
# Changes to this file will be over written
#   by the resource module builder.
#
# Changes should be made in the model used to
#   generate this file or in the resource module
#   builder template.
#
#############################################

"""
The module file for iosxr_lldp_interfaces
"""

from __future__ import absolute_import, division, print_function


__metaclass__ = type


DOCUMENTATION = """
module: iosxr_lldp_interfaces
short_description: Resource module to configure LLDP interfaces.
description:
- This module manages Link Layer Discovery Protocol (LLDP) attributes of interfaces
  on IOS-XR devices.
version_added: 1.0.0
notes:
- This module works with connection C(network_cli). See L(the IOS-XR Platform Options,../network/user_guide/platform_iosxr.html).
author: Nilashish Chakraborty (@nilashishc)
options:
  config:
    description: A dictionary of LLDP interfaces options.
    type: list
    elements: dict
    suboptions:
      name:
        description:
        - Name/Identifier of the interface or Ether-Bundle.
        type: str
      destination:
        description:
        - Specifies LLDP destination configuration on the interface.
        suboptions:
          mac_address:
            description:
            - Specifies the LLDP destination mac address on the interface.
            type: str
            choices:
            - ieee-nearest-bridge
            - ieee-nearest-non-tmpr-bridge
        type: dict
      receive:
        description:
        - Enable/disable LLDP RX on an interface.
        type: bool
      transmit:
        description:
        - Enable/disable LLDP TX on an interface.
        type: bool
  running_config:
    description:
    - This option is used only with state I(parsed).
    - The value of this option should be the output received from the IOS-XR device
      by executing the command B(show running-config int).
    - The state I(parsed) reads the configuration from C(running_config) option and
      transforms it into Ansible structured data as per the resource module's argspec
      and the value is then returned in the I(parsed) key within the result.
    type: str
  state:
    description:
    - The state of the configuration after module completion.
    type: str
    choices:
    - merged
    - replaced
    - overridden
    - deleted
    - parsed
    - rendered
    - gathered
    default: merged

"""
EXAMPLES = """
# Using merged
#
#
# ------------
# Before state
# ------------
#
#
# RP/0/RP0/CPU0:ios#sh run int
# Mon Aug 12 12:40:23.104 UTC
# interface TenGigE0/0/0/0
#  ipv4 address 192.0.2.11 255.255.255.192
# !
# interface preconfigure GigabitEthernet0/0/0/1
# !
# interface preconfigure GigabitEthernet0/0/0/2
# !
#
#

- name: Merge provided configuration with running configuration
  cisco.iosxr.iosxr_lldp_interfaces:
    config:
      - name: GigabitEthernet0/0/0/1
        destination:
          mac_address: ieee-nearest-non-tmpr-bridge
        transmit: false
      - name: GigabitEthernet0/0/0/2
        destination:
          mac_address: ieee-nearest-bridge
        receive: false
    state: merged


#
#
# ------------------------
# Module Execution Result
# ------------------------
#
#
# "before": [
#        {
#            "name": "TenGigE0/0/0/0"
#        },
#        {
#            "name": "GigabitEthernet0/0/0/1"
#        },
#        {
#            "name": "GigabitEthernet0/0/0/2"
#        }
# ]
#
# "commands": [
#        "interface GigabitEthernet0/0/0/2",
#        "lldp destination mac-address ieee-nearest-non-tmpr-bridge",
#        "lldp transmit disable",
#        "interface GigabitEthernet0/0/0/1",
#        "lldp receive disable",
#        "lldp destination mac-address ieee-nearest-bridge"
# ]
#
# "after": [
#        {
#            "name": "TenGigE0/0/0/0"
#        },
#        {
#            "destination": {
#                "mac_address": "ieee-nearest-bridge"
#            },
#            "name": "GigabitEthernet0/0/0/1",
#            "receive": false
#        },
#        {
#            "destination": {
#                "mac_address": "ieee-nearest-non-tmpr-bridge"
#            },
#            "name": "GigabitEthernet0/0/0/2",
#            "transmit": false
#        }
# ]
#
#
# ------------
# After state
# ------------
#
#
# RP/0/RP0/CPU0:ios#sh run int
# Mon Aug 12 12:49:51.517 UTC
# interface TenGigE0/0/0/0
#  ipv4 address 192.0.2.11 255.255.255.192
# !
# interface preconfigure GigabitEthernet0/0/0/1
#  lldp
#   receive disable
#   destination mac-address
#    ieee-nearest-bridge
#   !
#  !
# !
# interface preconfigure GigabitEthernet0/0/0/2
#  lldp
#   transmit disable
#   destination mac-address
#    ieee-nearest-non-tmpr-bridge
#   !
#  !
# !
#
#


# Using replaced
#
#
# -------------
# Before state
# -------------
#
#
# RP/0/RP0/CPU0:ios#sh run int
# Mon Aug 12 12:49:51.517 UTC
# interface TenGigE0/0/0/0
#  ipv4 address 192.0.2.11 255.255.255.192
# !
# interface preconfigure GigabitEthernet0/0/0/1
#  lldp
#   receive disable
#   destination mac-address
#    ieee-nearest-bridge
#   !
#  !
# !
# interface preconfigure GigabitEthernet0/0/0/2
#  lldp
#   transmit disable
#   destination mac-address
#    ieee-nearest-non-tmpr-bridge
#   !
#  !
# !
#
#

- name: >-
    Replace existing LLDP configurations of specified interfaces with provided
    configuration
  cisco.iosxr.iosxr_lldp_interfaces:
    config:
      - name: GigabitEthernet0/0/0/1
        destination:
          mac_address: ieee-nearest-non-tmpr-bridge
    state: replaced


#
#
# ------------------------
# Module Execution Result
# ------------------------
#
# "before": [
#        {
#            "name": "TenGigE0/0/0/0"
#        },
#        {
#            "destination": {
#                "mac_address": "ieee-nearest-bridge"
#            },
#            "name": "GigabitEthernet0/0/0/1",
#            "receive": false
#        },
#        {
#            "destination": {
#                "mac_address": "ieee-nearest-non-tmpr-bridge"
#            },
#            "name": "GigabitEthernet0/0/0/2",
#            "transmit": false
#        }
# ]
#
#
# "commands": [
#        "interface GigabitEthernet0/0/0/1",
#        "no lldp receive disable",
#        "lldp destination mac-address ieee-nearest-non-tmpr-bridge"
# ]
#
#
# "after": [
#        {
#            "name": "TenGigE0/0/0/0"
#        },
#        {
#            "destination": {
#                "mac_address": "ieee-nearest-non-tmpr-bridge"
#            },
#            "name": "GigabitEthernet0/0/0/1"
#        },
#        {
#            "destination": {
#                "mac_address": "ieee-nearest-non-tmpr-bridge"
#            },
#            "name": "GigabitEthernet0/0/0/2",
#            "transmit": false
#        }
# ]
#
#
# ------------
# After state
# ------------
#
#
# RP/0/RP0/CPU0:ios#sh run int
# Mon Aug 12 13:02:57.062 UTC
# interface TenGigE0/0/0/0
#  ipv4 address 192.0.2.11 255.255.255.192
# !
# interface preconfigure GigabitEthernet0/0/0/1
#  lldp
#   destination mac-address
#    ieee-nearest-non-tmpr-bridge
#   !
#  !
# !
# interface preconfigure GigabitEthernet0/0/0/2
#  lldp
#   transmit disable
#   destination mac-address
#    ieee-nearest-non-tmpr-bridge
#   !
#  !
# !
#
#


# Using overridden
#
#
# -------------
# Before state
# -------------
#
#
# RP/0/RP0/CPU0:ios#sh run int
# Mon Aug 12 13:15:40.465 UTC
# interface TenGigE0/0/0/0
#  ipv4 address 192.0.2.11 255.255.255.192
# !
# interface preconfigure GigabitEthernet0/0/0/1
#  lldp
#   receive disable
#   destination mac-address
#    ieee-nearest-bridge
#   !
#  !
# !
# interface preconfigure GigabitEthernet0/0/0/2
#  lldp
#   transmit disable
#   destination mac-address
#    ieee-nearest-non-tmpr-bridge
#   !
#  !
# !
#
#

- name: >-
    Override the LLDP configurations of all the interfaces with provided
    configurations
  cisco.iosxr.iosxr_lldp_interfaces:
    config:
      - name: GigabitEthernet0/0/0/1
        transmit: false
    state: overridden


#
#
# ------------------------
# Module Execution Result
# ------------------------
#
#
# "before": [
#        {
#            "name": "TenGigE0/0/0/0"
#        },
#        {
#            "destination": {
#                "mac_address": "ieee-nearest-bridge"
#            },
#            "name": "GigabitEthernet0/0/0/1",
#            "receive": false
#        },
#        {
#            "destination": {
#                "mac_address": "ieee-nearest-non-tmpr-bridge"
#            },
#            "name": "GigabitEthernet0/0/0/2",
#            "transmit": false
#        }
# ]
#
# "commands": [
#        "interface GigabitEthernet0/0/0/2",
#        "no lldp destination mac-address ieee-nearest-non-tmpr-bridge",
#        "no lldp transmit disable",
#        "interface GigabitEthernet0/0/0/1",
#        "no lldp destination mac-address ieee-nearest-bridge",
#        "no lldp receive disable",
#        "lldp transmit disable"
# ]
#
#
# "after": [
#        {
#            "name": "TenGigE0/0/0/0"
#        },
#        {
#            "name": "GigabitEthernet0/0/0/1",
#            "transmit": false
#        },
#        {
#            "name": "GigabitEthernet0/0/0/2"
#        }
# ]
#
#
# ------------
# After state
# ------------
#
#
# RP/0/RP0/CPU0:ios#sh run int
# Mon Aug 12 13:22:25.604 UTC
# interface TenGigE0/0/0/0
#  ipv4 address 192.0.2.11 255.255.255.192
# !
# interface preconfigure GigabitEthernet0/0/0/1
#  lldp
#   transmit disable
#  !
# !
# interface preconfigure GigabitEthernet0/0/0/2
# !
#
#


# Using deleted
#
#
# -------------
# Before state
# -------------
#
#
# RP/0/RP0/CPU0:ios#sh run int
# Mon Aug 12 13:26:21.498 UTC
# interface TenGigE0/0/0/0
#  ipv4 address 192.0.2.11 255.255.255.192
# !
# interface preconfigure GigabitEthernet0/0/0/1
#  lldp
#   receive disable
#   destination mac-address
#    ieee-nearest-bridge
#   !
#  !
# !
# interface preconfigure GigabitEthernet0/0/0/2
#  lldp
#   transmit disable
#   destination mac-address
#    ieee-nearest-non-tmpr-bridge
#   !
#  !
# !
#
#

- name: Delete LLDP configurations of all interfaces (Note - This won't delete the
    interfaces themselves)
  cisco.iosxr.iosxr_lldp_interfaces:
    state: deleted

#
#
#
# ------------------------
# Module Execution Result
# ------------------------
#
#
# "before": [
#        {
#            "name": "TenGigE0/0/0/0"
#        },
#        {
#            "destination": {
#                "mac_address": "ieee-nearest-bridge"
#            },
#            "name": "GigabitEthernet0/0/0/1",
#            "receive": false
#        },
#        {
#            "destination": {
#                "mac_address": "ieee-nearest-non-tmpr-bridge"
#            },
#            "name": "GigabitEthernet0/0/0/2",
#            "transmit": false
#        }
# ]
#
#
# "commands": [
#        "interface GigabitEthernet0/0/0/1",
#        "no lldp destination mac-address ieee-nearest-bridge",
#        "no lldp receive disable",
#        "interface GigabitEthernet0/0/0/2",
#        "no lldp destination mac-address ieee-nearest-non-tmpr-bridge",
#        "no lldp transmit disable"
# ]
#
#
# "after": [
#        {
#            "name": "TenGigE0/0/0/0"
#        },
#        {
#            "name": "GigabitEthernet0/0/0/1"
#        },
#        {
#            "name": "GigabitEthernet0/0/0/2"
#        }
# ]
#
#
# ------------
# After state
# ------------
#
#
# RP/0/RP0/CPU0:ios#sh run int
# Mon Aug 12 13:30:14.618 UTC
# interface TenGigE0/0/0/0
#  ipv4 address 192.0.2.11 255.255.255.192
# !
# interface preconfigure GigabitEthernet0/0/0/1
# !
# interface preconfigure GigabitEthernet0/0/0/2
# !
#
#
# Using parsed:
# parsed.cfg

# interface TenGigE0/0/0/0
#  ipv4 address 192.0.2.11 255.255.255.192
# !
# interface preconfigure GigabitEthernet0/0/0/1
#  lldp
#   receive disable
#   destination mac-address
#    ieee-nearest-bridge
#   !
#  !
# !
# interface preconfigure GigabitEthernet0/0/0/2
#  lldp
#   transmit disable
#   destination mac-address
#    ieee-nearest-non-tmpr-bridge

- name: Convert lacp interfaces config to argspec without connecting to the appliance
  cisco.iosxr.iosxr_lldp_interfaces:
    running_config: "{{ lookup('file', './parsed.cfg') }}"
    state: parsed

# ------------------------
# Module Execution Result
# ------------------------

# parsed: [
#   - name: GigabitEthernet0/0/0/1
#       destination:
#         mac_address: ieee-nearest-non-tmpr-bridge
#       transmit: False

#     - name: GigabitEthernet0/0/0/2
#       destination:
#         mac_address: ieee-nearest-bridge
#       receive: False
#   ]

# Using gathered:
# Device config:

# RP/0/RP0/CPU0:ios#sh run int
# Mon Aug 12 12:49:51.517 UTC
# interface TenGigE0/0/0/0
#  ipv4 address 192.0.2.11 255.255.255.192
# !
# interface preconfigure GigabitEthernet0/0/0/1
#  lldp
#   receive disable
#   destination mac-address
#    ieee-nearest-bridge
#   !
#  !
# !
# interface preconfigure GigabitEthernet0/0/0/2
#  lldp
#   transmit disable
#   destination mac-address
#    ieee-nearest-non-tmpr-bridge

- name: Gather IOSXR lldp interfaces configuration
  cisco.iosxr.iosxr_lldp_interfaces:
    config:
    state: gathered

# ------------------------
# Module Execution Result
# ------------------------

#   gathered:
#     - name: GigabitEthernet0/0/0/1
#       destination:
#         mac_address: ieee-nearest-non-tmpr-bridge
#       transmit: False

#     - name: GigabitEthernet0/0/0/2
#       destination:
#         mac_address: ieee-nearest-bridge
#       receive: False

# Using rendred:
- name: Render platform specific commands from task input using rendered state
  cisco.iosxr.iosxr_lldp_interfaces:
    config:
      - name: GigabitEthernet0/0/0/1
        destination:
          mac_address: ieee-nearest-non-tmpr-bridge
        transmit: false
      - name: GigabitEthernet0/0/0/2
        destination:
          mac_address: ieee-nearest-bridge
        receive: false
    state: rendered
# ------------------------
# Module Execution Result
# ------------------------

# "rendered": [
#        "interface GigabitEthernet0/0/0/2",
#        "lldp destination mac-address ieee-nearest-non-tmpr-bridge",
#        "lldp transmit disable",
#        "interface GigabitEthernet0/0/0/1",
#        "lldp receive disable",
#        "lldp destination mac-address ieee-nearest-bridge"
# ]
"""
RETURN = """
before:
  description: The configuration as structured data prior to module invocation.
  returned: always
  type: list
  sample: >
    The configuration returned will always be in the same format
     of the parameters above.
after:
  description: The configuration as structured data after module completion.
  returned: when changed
  type: list
  sample: >
    The configuration returned will always be in the same format
     of the parameters above.
commands:
  description: The set of commands pushed to the remote device.
  returned: always
  type: list
  sample: ['interface GigabitEthernet0/0/0/1', 'lldp destination mac-address ieee-nearest-non-tmpr-bridge', 'no lldp transmit disable']
"""


from ansible.module_utils.basic import AnsibleModule

from ansible_collections.cisco.iosxr.plugins.module_utils.network.iosxr.argspec.lldp_interfaces.lldp_interfaces import (
    Lldp_interfacesArgs,
)
from ansible_collections.cisco.iosxr.plugins.module_utils.network.iosxr.config.lldp_interfaces.lldp_interfaces import (
    Lldp_interfaces,
)


def main():
    """
    Main entry point for module execution

    :returns: the result form module invocation
    """
    required_if = [
        ("state", "merged", ("config",)),
        ("state", "replaced", ("config",)),
        ("state", "overridden", ("config",)),
        ("state", "rendered", ("config",)),
        ("state", "parsed", ("running_config",)),
    ]
    mutually_exclusive = [("config", "running_config")]
    module = AnsibleModule(
        argument_spec=Lldp_interfacesArgs.argument_spec,
        required_if=required_if,
        supports_check_mode=True,
        mutually_exclusive=mutually_exclusive,
    )

    result = Lldp_interfaces(module).execute_module()
    module.exit_json(**result)


if __name__ == "__main__":
    main()



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)


DOCUMENTATION = r"""
---
module: maps_import_status_info
short_description: Information module for Maps Import Status Info
description:
- This module represents an alias of the module maps_import_status_v1_info
version_added: '6.14.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  importContextUuid:
    description:
    - >
      ImportContextUuid path parameter. The unique import context UUID given by a previous and recent call to
      maps/import/start API.
    type: str
requirements:
- dnacentersdk >= 2.4.9
- python >= 3.5
seealso:
- name: Cisco DNA Center documentation for Sites ImportMapArchiveImportStatusV1
  description: Complete reference of the ImportMapArchiveImportStatusV1 API.
  link: https://developer.cisco.com/docs/dna-center/#!import-map-archive-import-status
notes:
  - SDK Method used are
    sites.Sites.import_map_archive_import_status_v1,

  - Paths used are
    get /dna/intent/api/v1/maps/import/{importContextUuid}/status,
  - It should be noted that this module is an alias of maps_import_status_v1_info

"""

EXAMPLES = r"""
- name: Get all Maps Import Status Info
  cisco.dnac.maps_import_status_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    importContextUuid: string
  register: result

"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "auditLog": {
        "children": [
          "string"
        ],
        "entitiesCount": [
          {
            "key": 0
          }
        ],
        "entityName": "string",
        "entityType": "string",
        "errorEntitiesCount": [
          {
            "key": 0
          }
        ],
        "errors": [
          {
            "message": "string"
          }
        ],
        "infos": [
          {
            "message": "string"
          }
        ],
        "matchingEntitiesCount": [
          {
            "key": 0
          }
        ],
        "subTasksRootTaskId": "string",
        "successfullyImportedFloors": [
          "string"
        ],
        "warnings": [
          {
            "message": "string"
          }
        ]
      },
      "status": "string",
      "uuid": {
        "leastSignificantBits": 0,
        "mostSignificantBits": 0
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: disasterrecovery_system_status_v1_info
short_description: Information module for Disasterrecovery System Status V1
description:
- Get all Disasterrecovery System Status V1.
- Detailed and Summarized status of DR components Active, Standby and Witness system's health .
version_added: '6.16.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
requirements:
- dnacentersdk >= 2.4.9
- python >= 3.5
notes:
  - SDK Method used are
    disaster_recovery.DisasterRecovery.disaster_recovery_status_v1,

  - Paths used are
    get /dna/intent/api/v1/disasterrecovery/system/status,

"""

EXAMPLES = r"""
- name: Get all Disasterrecovery System Status V1
  cisco.dnac.disasterrecovery_system_status_v1_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
  register: result

"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "ipconfig": [
        {
          "interface": "string",
          "vip": true,
          "ip": "string"
        }
      ],
      "site": "string",
      "main": {
        "ipconfig": [
          {
            "interface": "string",
            "vip": true,
            "ip": "string"
          }
        ],
        "state": "string",
        "nodes": [
          {
            "hostname": "string",
            "state": "string",
            "ipaddresses": [
              {
                "interface": "string",
                "vip": true,
                "ip": "string"
              }
            ]
          }
        ]
      },
      "recovery": {
        "ipconfig": [
          {
            "interface": "string",
            "vip": true,
            "ip": "string"
          }
        ],
        "state": "string",
        "nodes": [
          {
            "hostname": "string",
            "state": "string",
            "ipconfig": [
              {
                "interface": "string",
                "vip": true,
                "ip": "string"
              }
            ]
          }
        ]
      },
      "witness": {
        "ipconfig": [
          {
            "interface": "string",
            "vip": true,
            "ip": "string"
          }
        ],
        "state": "string",
        "nodes": [
          {
            "hostname": "string",
            "state": "string",
            "ipconfig": [
              {
                "interface": "string",
                "vip": true,
                "ip": "string"
              }
            ]
          }
        ]
      },
      "state": "string",
      "ipsec-tunnel": [
        {
          "side_a": "string",
          "side_b": "string",
          "status": "string"
        }
      ]
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: pnp_device_count_v1_info
short_description: Information module for Pnp Device Count V1
description:
- Get all Pnp Device Count V1.
- Returns the device count based on filter criteria. This is useful for pagination.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  serialNumber:
    description:
    - SerialNumber query parameter. Device Serial Number.
    elements: str
    type: list
  state_:
    description:
    - State query parameter. Device State.
    elements: str
    type: list
  onbState:
    description:
    - OnbState query parameter. Device Onboarding State.
    elements: str
    type: list
  name:
    description:
    - Name query parameter. Device Name.
    elements: str
    type: list
  pid:
    description:
    - Pid query parameter. Device ProductId.
    elements: str
    type: list
  source:
    description:
    - Source query parameter. Device Source.
    elements: str
    type: list
  workflowId:
    description:
    - WorkflowId query parameter. Device Workflow Id.
    elements: str
    type: list
  workflowName:
    description:
    - WorkflowName query parameter. Device Workflow Name.
    elements: str
    type: list
  smartAccountId:
    description:
    - SmartAccountId query parameter. Device Smart Account.
    elements: str
    type: list
  virtualAccountId:
    description:
    - VirtualAccountId query parameter. Device Virtual Account.
    elements: str
    type: list
  lastContact:
    description:
    - LastContact query parameter. Device Has Contacted lastContact > 0.
    type: bool
requirements:
- dnacentersdk >= 2.4.9
- python >= 3.5
seealso:
- name: Cisco DNA Center documentation for Device Onboarding (PnP) GetDeviceCountV1
  description: Complete reference of the GetDeviceCountV1 API.
  link: https://developer.cisco.com/docs/dna-center/#!get-device-count
notes:
  - SDK Method used are
    device_onboarding_pnp.DeviceOnboardingPnp.get_device_count,

  - Paths used are
    get /dna/intent/api/v1/onboarding/pnp-device/count,

"""

EXAMPLES = r"""
- name: Get all Pnp Device Count V1
  cisco.dnac.pnp_device_count_v1_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    serialNumber: []
    state_: []
    onbState: []
    name: []
    pid: []
    source: []
    workflowId: []
    workflowName: []
    smartAccountId: []
    virtualAccountId: []
    lastContact: True
  register: result

"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": 0
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)


DOCUMENTATION = r"""
---
module: sda_fabric_zones
short_description: Resource module for Sda Fabric Zones
description:
- This module represents an alias of the module sda_fabric_zones_v1
version_added: '6.14.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  id:
    description: Id path parameter. ID of the fabric zone.
    type: str
  payload:
    description: Sda Fabric Zones's payload.
    elements: dict
    suboptions:
      authenticationProfileName:
        description: Authentication profile used for this fabric.
        type: str
      id:
        description: ID of the fabric zone (updating this field is not allowed).
        type: str
      siteId:
        description: ID of the network hierarchy (updating this field is not allowed).
        type: str
    type: list
requirements:
- dnacentersdk >= 2.4.9
- python >= 3.5
seealso:
- name: Cisco DNA Center documentation for SDA AddFabricZoneV1
  description: Complete reference of the AddFabricZoneV1 API.
  link: https://developer.cisco.com/docs/dna-center/#!add-fabric-zone
- name: Cisco DNA Center documentation for SDA DeleteFabricZoneByIdV1
  description: Complete reference of the DeleteFabricZoneByIdV1 API.
  link: https://developer.cisco.com/docs/dna-center/#!delete-fabric-zone-by-id
- name: Cisco DNA Center documentation for SDA UpdateFabricZoneV1
  description: Complete reference of the UpdateFabricZoneV1 API.
  link: https://developer.cisco.com/docs/dna-center/#!update-fabric-zone
notes:
  - SDK Method used are
    sda.Sda.add_fabric_zone_v1,
    sda.Sda.delete_fabric_zone_by_id_v1,
    sda.Sda.update_fabric_zone_v1,

  - Paths used are
    post /dna/intent/api/v1/sda/fabricZones,
    delete /dna/intent/api/v1/sda/fabricZones/{id},
    put /dna/intent/api/v1/sda/fabricZones,
  - It should be noted that this module is an alias of sda_fabric_zones_v1

"""

EXAMPLES = r"""
- name: Update all
  cisco.dnac.sda_fabric_zones:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    payload:
    - authenticationProfileName: string
      id: string
      siteId: string

- name: Create
  cisco.dnac.sda_fabric_zones:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    payload:
    - authenticationProfileName: string
      siteId: string

- name: Delete by id
  cisco.dnac.sda_fabric_zones:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    id: string

"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: discovery_v1_info
short_description: Information module for Discovery V1
description:
- Get Discovery V1 by id.
- Returns discovery by Discovery ID. Discovery ID can be obtained using the "Get Discoveries by range" API.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
    - Id path parameter. Discovery ID.
    type: str
requirements:
- dnacentersdk >= 2.4.9
- python >= 3.5
seealso:
- name: Cisco DNA Center documentation for Discovery GetDiscoveryByIdV1
  description: Complete reference of the GetDiscoveryByIdV1 API.
  link: https://developer.cisco.com/docs/dna-center/#!get-discovery-by-id
notes:
  - SDK Method used are
    discovery.Discovery.get_discovery_by_id_v1,

  - Paths used are
    get /dna/intent/api/v1/discovery/{id},

"""

EXAMPLES = r"""
- name: Get Discovery V1 by id
  cisco.dnac.discovery_v1_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
  register: result

"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "attributeInfo": {},
        "cdpLevel": 0,
        "deviceIds": "string",
        "discoveryCondition": "string",
        "discoveryStatus": "string",
        "discoveryType": "string",
        "enablePasswordList": "string",
        "globalCredentialIdList": [
          "string"
        ],
        "httpReadCredential": {
          "comments": "string",
          "credentialType": "string",
          "description": "string",
          "id": "string",
          "instanceTenantId": "string",
          "instanceUuid": "string",
          "password": "string",
          "port": 0,
          "secure": true,
          "username": "string"
        },
        "httpWriteCredential": {
          "comments": "string",
          "credentialType": "string",
          "description": "string",
          "id": "string",
          "instanceTenantId": "string",
          "instanceUuid": "string",
          "password": "string",
          "port": 0,
          "secure": true,
          "username": "string"
        },
        "id": "string",
        "ipAddressList": "string",
        "ipFilterList": "string",
        "isAutoCdp": true,
        "lldpLevel": 0,
        "name": "string",
        "netconfPort": "string",
        "numDevices": 0,
        "parentDiscoveryId": "string",
        "passwordList": "string",
        "preferredMgmtIPMethod": "string",
        "protocolOrder": "string",
        "retryCount": 0,
        "snmpAuthPassphrase": "string",
        "snmpAuthProtocol": "string",
        "snmpMode": "string",
        "snmpPrivPassphrase": "string",
        "snmpPrivProtocol": "string",
        "snmpRoCommunity": "string",
        "snmpRoCommunityDesc": "string",
        "snmpRwCommunity": "string",
        "snmpRwCommunityDesc": "string",
        "snmpUserName": "string",
        "timeOut": 0,
        "updateMgmtIp": true,
        "userNameList": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)


DOCUMENTATION = r"""
---
module: network_create
short_description: Resource module for Network Create
description:
- This module represents an alias of the module network_create_v1
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  settings:
    description: Network Create's settings.
    suboptions:
      clientAndEndpoint_aaa:
        description: Network Create's clientAndEndpoint_aaa.
        suboptions:
          ipAddress:
            description: IP address for ISE serve (eg 1.1.1.4).
            type: str
          network:
            description: IP address for AAA or ISE server (eg 2.2.2.1).
            type: str
          protocol:
            description: Protocol for AAA or ISE serve (eg RADIUS).
            type: str
          servers:
            description: Server type AAA or ISE server (eg AAA).
            type: str
          sharedSecret:
            description: Shared secret for ISE server.
            type: str
        type: dict
      dhcpServer:
        description: DHCP Server IP (eg 1.1.1.1).
        elements: str
        type: list
      dnsServer:
        description: Network Create's dnsServer.
        suboptions:
          domainName:
            description: Domain Name of DHCP (eg; cisco).
            type: str
          primaryIpAddress:
            description: Primary IP Address for DHCP (eg 2.2.2.2).
            type: str
          secondaryIpAddress:
            description: Secondary IP Address for DHCP (eg 3.3.3.3).
            type: str
        type: dict
      messageOfTheday:
        description: Network Create's messageOfTheday.
        suboptions:
          bannerMessage:
            description: Massage for Banner message (eg; Good day).
            type: str
          retainExistingBanner:
            description: Retain existing Banner Message (eg "true" or "false").
            type: str
        type: dict
      netflowcollector:
        description: Network Create's netflowcollector.
        suboptions:
          ipAddress:
            description: IP Address for NetFlow collector (eg 3.3.3.1).
            type: str
          port:
            description: Port for NetFlow Collector (eg; 443).
            type: float
        type: dict
      network_aaa:
        description: Network Create's network_aaa.
        suboptions:
          ipAddress:
            description: IP address for AAA and ISE server (eg 1.1.1.1).
            type: str
          network:
            description: IP Address for AAA or ISE server (eg 2.2.2.2).
            type: str
          protocol:
            description: Protocol for AAA or ISE serve (eg RADIUS).
            type: str
          servers:
            description: Server type for AAA Network (eg AAA).
            type: str
          sharedSecret:
            description: Shared secret for ISE Server.
            type: str
        type: dict
      ntpServer:
        description: IP address for NTP server (eg 1.1.1.2).
        elements: str
        type: list
      snmpServer:
        description: Network Create's snmpServer.
        suboptions:
          configureDnacIP:
            description: Configuration DNAC IP for SNMP Server (eg true).
            type: bool
          ipAddresses:
            description: IP Address for SNMP Server (eg 4.4.4.1).
            elements: str
            type: list
        type: dict
      syslogServer:
        description: Network Create's syslogServer.
        suboptions:
          configureDnacIP:
            description: Configuration DNAC IP for syslog server (eg true).
            type: bool
          ipAddresses:
            description: IP Address for syslog server (eg 4.4.4.4).
            elements: str
            type: list
        type: dict
      timezone:
        description: Input for time zone (eg Africa/Abidjan).
        type: str
    type: dict
  siteId:
    description: SiteId path parameter. Site id to which site details to associate with
      the network settings.
    type: str
requirements:
- dnacentersdk >= 2.4.9
- python >= 3.5
seealso:
- name: Cisco DNA Center documentation for Network Settings CreateNetworkV1
  description: Complete reference of the CreateNetworkV1 API.
  link: https://developer.cisco.com/docs/dna-center/#!create-network
notes:
  - SDK Method used are
    network_settings.NetworkSettings.create_network_v1,

  - Paths used are
    post /dna/intent/api/v1/network/{siteId},
  - It should be noted that this module is an alias of network_create_v1

"""

EXAMPLES = r"""
- name: Create
  cisco.dnac.network_create:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: '{{my_headers | from_json}}'
    settings:
      clientAndEndpoint_aaa:
        ipAddress: string
        network: string
        protocol: string
        servers: string
        sharedSecret: string
      dhcpServer:
      - string
      dnsServer:
        domainName: string
        primaryIpAddress: string
        secondaryIpAddress: string
      messageOfTheday:
        bannerMessage: string
        retainExistingBanner: string
      netflowcollector:
        ipAddress: string
        port: 0
      network_aaa:
        ipAddress: string
        network: string
        protocol: string
        servers: string
        sharedSecret: string
      ntpServer:
      - string
      snmpServer:
        configureDnacIP: true
        ipAddresses:
        - string
      syslogServer:
        configureDnacIP: true
        ipAddresses:
        - string
      timezone: string
    siteId: string

"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "executionId": "string",
      "executionStatusUrl": "string",
      "message": "string"
    }
"""



#!/usr/bin/python
#
# Copyright (c) 2019 Yunge Zhu, <yungez@microsoft.com>
#
# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

from __future__ import absolute_import, division, print_function
__metaclass__ = type


DOCUMENTATION = '''
---
module: azure_rm_rediscachefirewallrule
version_added: "0.1.2"
short_description: Manage Azure Cache for Redis Firewall rules
description:
    - Create, update and delete Azure Cache for Redis Firewall rules.

options:
    resource_group:
        description:
            - Name of the resource group to which the resource belongs.
        required: True
        type: str
    cache_name:
        description:
            - Name of the Azure Cache for Redis.
        required: True
        type: str
    name:
        description:
            - Name of the Firewall rule.
        required: True
        type: str
    start_ip_address:
        description:
            - The start IP address of the Azure Cache for Redis Firewall rule. Must be IPv4 format.
            - Required when creating Firewall rule.
        type: str
    end_ip_address:
        description:
            - The end IP address of the Azure Cache for Redis Firewall rule. Must be IPv4 format.
            - Required when creating Firewall rule.
        type: str
    state:
        description:
            - Assert the state of the Firewall rule of Azure Cache for Redis.
            - Use C(present) to create or update Firewall rule of Azure Cache for Redis and C(absent) to delete it.
        default: present
        type: str
        choices:
            - absent
            - present

extends_documentation_fragment:
    - azure.azcollection.azure

author:
    - Yunge Zhu(@yungezz)

'''

EXAMPLES = '''
- name: Create a Firewall rule for Azure Cache for Redis
  azure_rm_rediscachefirewallrule:
    resource_group: myResourceGroup
    cache_name: myRedisCache
    name: myRule
    start_ip_address: 192.168.1.1
    end_ip_address: 192.168.1.4

- name: Update a Firewall rule for Azure Cache for Redis
  azure_rm_rediscachefirewallrule:
    resource_group: myResourceGroup
    cache_name: myRedisCache
    name: myRule
    end_ip_address: 192.168.1.5
'''

RETURN = '''
id:
    description:
        - Id of the Azure Cache for Redis.
    returned: always
    type: str
    sample: "/subscriptions/xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx/resourceGroups/myResourceGroup/providers/Microsoft.Cache/redis/myRedis/firewallRules/myRule"
'''

try:
    from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common import AzureRMModuleBase
    from azure.core.polling import LROPoller
    from azure.core.exceptions import ResourceNotFoundError
    from azure.mgmt.redis import RedisManagementClient
    from azure.mgmt.redis.models import (
        RedisFirewallRule
    )
except ImportError:
    # This is handled in azure_rm_common
    pass


def firewall_rule_to_dict(rule):
    return dict(
        id=rule.id,
        name=rule.name,
        start_ip_address=rule.start_ip,
        end_ip_address=rule.end_ip,
        type=rule.type
    )


class Actions:
    NoAction, CreateUpdate, Delete = range(3)


class AzureRMRedisCacheFirewallRule(AzureRMModuleBase):
    """Configuration class for an Azure RM Cache for Redis Firewall Rule resource"""

    def __init__(self):
        self.module_arg_spec = dict(
            resource_group=dict(
                type='str',
                required=True
            ),
            name=dict(
                type='str',
                required=True
            ),
            cache_name=dict(
                type='str',
                required=True
            ),
            start_ip_address=dict(
                type='str'
            ),
            end_ip_address=dict(
                type='str'
            ),
            state=dict(
                type='str',
                default='present',
                choices=['present', 'absent']
            )
        )

        self._client = None

        self.resource_group = None
        self.name = None
        self.cache_name = None

        self.start_ip_address = None
        self.end_ip_address = None

        self.results = dict(
            changed=False,
            id=None
        )
        self.state = None

        self.to_do = Actions.NoAction

        super(AzureRMRedisCacheFirewallRule, self).__init__(derived_arg_spec=self.module_arg_spec,
                                                            supports_check_mode=True,
                                                            supports_tags=False)

    def exec_module(self, **kwargs):
        """Main module execution method"""

        for key in list(self.module_arg_spec.keys()):
            setattr(self, key, kwargs[key])

        old_response = None
        response = None

        # get management client
        self._client = self.get_mgmt_svc_client(RedisManagementClient,
                                                base_url=self._cloud_environment.endpoints.resource_manager,
                                                api_version='2024-03-01')

        # check if the firewall rule exists
        old_response = self.get()

        if old_response:
            self.results['id'] = old_response['id']

        if self.state == 'present':
            # if firewall rule not exists
            if not old_response:
                self.log("Firewall Rule of Azure Cache for Redis doesn't exist")

                self.to_do = Actions.CreateUpdate

            else:
                # redis exists already, do update
                self.log("Firewall Rule of Azure Cache for Redis already exists")

                if self.start_ip_address is None:
                    self.start_ip_address = old_response['start_ip_address']
                if self.end_ip_address is None:
                    self.end_ip_address = old_response['end_ip_address']

                # check if update
                if self.check_update(old_response):
                    self.to_do = Actions.CreateUpdate

        elif self.state == 'absent':
            if old_response:
                self.log("Delete Firewall Rule of Azure Cache for Redis")
                self.results['id'] = old_response['id']
                self.to_do = Actions.Delete
            else:
                self.results['changed'] = False
                self.log("Azure Cache for Redis {0} doesn't exist.".format(self.name))

        if self.to_do == Actions.CreateUpdate:
            self.log('Need to Create/Update Firewall rule of Azure Cache for Redis')
            self.results['changed'] = True

            if self.check_mode:
                return self.results

            response = self.create_or_update()
            self.results['id'] = response['id']

        if self.to_do == Actions.Delete:
            self.log('Delete Firewall rule of Azure Cache for Redis')
            self.results['changed'] = True

            if self.check_mode:
                return self.results

            self.delete()
            self.log('Firewall rule of Azure Cache for Redis deleted')

        return self.results

    def check_update(self, existing):
        if self.start_ip_address and self.start_ip_address != existing['start_ip_address']:
            self.log("start_ip_address diff: origin {0} / update {1}".format(existing['start_ip_address'], self.start_ip_address))
            return True
        if self.end_ip_address and self.end_ip_address != existing['end_ip_address']:
            self.log("end_ip_address diff: origin {0} / update {1}".format(existing['end_ip_address'], self.end_ip_address))
            return True
        return False

    def create_or_update(self):
        '''
        Creates Firewall rule of Azure Cache for Redis with the specified configuration.

        :return: deserialized Firewall rule of Azure Cache for Redis state dictionary
        '''
        self.log(
            "Creating Firewall rule of Azure Cache for Redis {0}".format(self.name))

        try:
            params = RedisFirewallRule(
                name=self.name,
                start_ip=self.start_ip_address,
                end_ip=self.end_ip_address,
            )
            response = self._client.firewall_rules.create_or_update(resource_group_name=self.resource_group,
                                                                    cache_name=self.cache_name,
                                                                    rule_name=self.name,
                                                                    parameters=params)
            if isinstance(response, LROPoller):
                response = self.get_poller_result(response)

        except Exception as exc:
            self.log('Error attempting to create/update Firewall rule of Azure Cache for Redis.')
            self.fail(
                "Error creating/updating Firewall rule of Azure Cache for Redis: {0}".format(str(exc)))
        return firewall_rule_to_dict(response)

    def delete(self):
        '''
        Deletes specified Firewall rule of Azure Cache for Redis in the specified subscription and resource group.

        :return: True
        '''
        self.log("Deleting the Firewall rule of Azure Cache for Redis {0}".format(self.name))
        try:
            self._client.firewall_rules.delete(resource_group_name=self.resource_group,
                                               rule_name=self.name,
                                               cache_name=self.cache_name)
        except Exception as e:
            self.log('Error attempting to delete the Firewall rule of Azure Cache for Redis.')
            self.fail(
                "Error deleting the Firewall rule of Azure Cache for Redis: {0}".format(str(e)))
        return True

    def get(self):
        '''
        Gets the properties of the specified Firewall rule of Azure Cache for Redis.

        :return: Azure Cache for Redis Firewall Rule instance state dictionary
        '''
        self.log("Checking if the Firewall Rule {0} is present".format(self.name))

        response = None

        try:
            response = self._client.firewall_rules.get(resource_group_name=self.resource_group,
                                                       rule_name=self.name,
                                                       cache_name=self.cache_name)

            self.log("Response : {0}".format(response))
            self.log("Redis Firewall Rule : {0} found".format(response.name))
            return firewall_rule_to_dict(response)

        except ResourceNotFoundError:
            self.log("Didn't find Azure Redis Firewall rule {0} in resource group {1}".format(
                self.name, self.resource_group))

        return False


def main():
    """Main execution"""
    AzureRMRedisCacheFirewallRule()


if __name__ == '__main__':
    main()



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)


DOCUMENTATION = r"""
---
module: sites_ntp_settings
short_description: Resource module for Sites Ntp Settings
description:
- This module represents an alias of the module sites_ntp_settings_v1
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  id:
    description: Id path parameter. Site Id.
    type: str
  ntp:
    description: Sites Ntp Settings's ntp.
    suboptions:
      servers:
        description: NTP servers to facilitate system clock synchronization for your
          network. Max 10.
        elements: str
        type: list
    type: dict
requirements:
- dnacentersdk >= 2.4.9
- python >= 3.5
seealso:
- name: Cisco DNA Center documentation for Network Settings SetNTPSettingsForASiteV1
  description: Complete reference of the SetNTPSettingsForASiteV1 API.
  link: https://developer.cisco.com/docs/dna-center/#!set-ntp-settings-for-a-site
notes:
  - SDK Method used are
    network_settings.NetworkSettings.set_n_t_p_settings_for_a_site_v1,

  - Paths used are
    put /dna/intent/api/v1/sites/{id}/ntpSettings,
  - It should be noted that this module is an alias of sites_ntp_settings_v1

"""

EXAMPLES = r"""
- name: Update all
  cisco.dnac.sites_ntp_settings:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    id: string
    ntp:
      servers:
      - string

"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "version": "string",
      "response": {
        "url": "string",
        "taskId": "string"
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: pnp_device_config_preview_v1
short_description: Resource module for Pnp Device Config Preview V1
description:
- Manage operation create of the resource Pnp Device Config Preview V1.
- Triggers a preview for site-based Day 0 Configuration.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  deviceId:
    description: Pnp Device Config Preview's deviceId.
    type: str
  siteId:
    description: Pnp Device Config Preview's siteId.
    type: str
  type:
    description: Pnp Device Config Preview's type.
    type: str
requirements:
- dnacentersdk >= 2.4.9
- python >= 3.5
seealso:
- name: Cisco DNA Center documentation for Device Onboarding (PnP) PreviewConfigV1
  description: Complete reference of the PreviewConfigV1 API.
  link: https://developer.cisco.com/docs/dna-center/#!preview-config
notes:
  - SDK Method used are
    device_onboarding_pnp.DeviceOnboardingPnp.preview_config_v1,

  - Paths used are
    post /dna/intent/api/v1/onboarding/pnp-device/site-config-preview,

"""

EXAMPLES = r"""
- name: Create
  cisco.dnac.pnp_device_config_preview_v1:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    deviceId: string
    siteId: string
    type: string

"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "complete": true,
        "config": "string",
        "error": true,
        "errorMessage": "string",
        "expiredTime": 0,
        "rfProfile": "string",
        "sensorProfile": "string",
        "siteId": "string",
        "startTime": 0,
        "taskId": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

from __future__ import absolute_import, division, print_function

__metaclass__ = type

ANSIBLE_METADATA = {"metadata_version": "1.1", "status": ["preview"], "supported_by": "certified"}

DOCUMENTATION = r"""
---
module: aci_syslog_group
short_description: Manage Syslog groups (syslog:Group, syslog:Console, syslog:File and syslog:Prof)
description:
- Manage syslog groups.
options:
  admin_state:
    description:
    - Administrative state of the syslog group
    type: str
    choices: [ enabled, disabled ]
  console_logging:
    description:
    - Log events to console
    type: str
    choices: [ enabled, disabled ]
  console_log_severity:
    description:
    - Severity of events to log to console
    type: str
    choices: [ alerts, critical, debugging, emergencies, error, information, notifications, warnings ]
  local_file_logging:
    description:
    - Log to local file
    type: str
    choices: [ enabled, disabled ]
  local_file_log_severity:
    description:
    - Severity of events to log to local file
    type: str
    choices: [ alerts, critical, debugging, emergencies, error, information, notifications, warnings ]
  format:
    description:
    - Format of the syslog messages. If omitted when creating a group, ACI defaults to using aci format.
    type: str
    choices: [ aci, nxos ]
  include_ms:
    description:
    - Include milliseconds in log timestamps
    type: bool
  include_time_zone:
    description:
    - Include timezone in log timestamps
    type: bool
  name:
    description:
    - Name of the syslog group
    type: str
    aliases: [ syslog_group, syslog_group_name ]
  state:
    description:
    - Use C(present) or C(absent) for adding or removing.
    - Use C(query) for listing an object or multiple objects.
    type: str
    choices: [ absent, present, query ]
    default: present
extends_documentation_fragment:
- cisco.aci.aci
- cisco.aci.annotation

seealso:
- name: APIC Management Information Model reference
  description: More information about the internal APIC classes B(syslog:Group), B(syslog:Console), B(syslog:File) and B(syslog:Prof).
  link: https://developer.cisco.com/docs/apic-mim-ref/
author:
- Tim Cragg (@timcragg)
"""

EXAMPLES = r"""
- name: Create a syslog group
  cisco.aci.aci_syslog_group:
    host: apic
    username: admin
    password: SomeSecretPassword
    name: my_syslog_group
    local_file_logging: enabled
    local_file_log_severity: warnings
    console_logging: enabled
    console_log_severity: critical
    state: present
  delegate_to: localhost

- name: Disable logging to local file
  cisco.aci.aci_syslog_group:
    host: apic
    username: admin
    password: SomeSecretPassword
    name: my_syslog_group
    local_file_logging: disabled
    state: present
  delegate_to: localhost

- name: Remove a syslog group
  cisco.aci.aci_syslog_group:
    host: apic
    username: admin
    password: SomeSecretPassword
    name: my_syslog_group
    state: absent
  delegate_to: localhost

- name: Query a syslog group
  cisco.aci.aci_syslog_group:
    host: apic
    username: admin
    password: SomeSecretPassword
    name: my_syslog_group
    state: query
  delegate_to: localhost
  register: query_result

- name: Query all syslog groups
  cisco.aci.aci_syslog_group:
    host: apic
    username: admin
    password: SomeSecretPassword
    state: query
  delegate_to: localhost
  register: query_result
"""

RETURN = r"""
current:
  description: The existing configuration from the APIC after the module has finished
  returned: success
  type: list
  sample:
    [
        {
            "fvTenant": {
                "attributes": {
                    "descr": "Production environment",
                    "dn": "uni/tn-production",
                    "name": "production",
                    "nameAlias": "",
                    "ownerKey": "",
                    "ownerTag": ""
                }
            }
        }
    ]
error:
  description: The error information as returned from the APIC
  returned: failure
  type: dict
  sample:
    {
        "code": "122",
        "text": "unknown managed object class foo"
    }
raw:
  description: The raw output returned by the APIC REST API (xml or json)
  returned: parse error
  type: str
  sample: '<?xml version="1.0" encoding="UTF-8"?><imdata totalCount="1"><error code="122" text="unknown managed object class foo"/></imdata>'
sent:
  description: The actual/minimal configuration pushed to the APIC
  returned: info
  type: list
  sample:
    {
        "fvTenant": {
            "attributes": {
                "descr": "Production environment"
            }
        }
    }
previous:
  description: The original configuration from the APIC before the module has started
  returned: info
  type: list
  sample:
    [
        {
            "fvTenant": {
                "attributes": {
                    "descr": "Production",
                    "dn": "uni/tn-production",
                    "name": "production",
                    "nameAlias": "",
                    "ownerKey": "",
                    "ownerTag": ""
                }
            }
        }
    ]
proposed:
  description: The assembled configuration from the user-provided parameters
  returned: info
  type: dict
  sample:
    {
        "fvTenant": {
            "attributes": {
                "descr": "Production environment",
                "name": "production"
            }
        }
    }
filter_string:
  description: The filter string used for the request
  returned: failure or debug
  type: str
  sample: ?rsp-prop-include=config-only
method:
  description: The HTTP method used for the request to the APIC
  returned: failure or debug
  type: str
  sample: POST
response:
  description: The HTTP response from the APIC
  returned: failure or debug
  type: str
  sample: OK (30 bytes)
status:
  description: The HTTP status from the APIC
  returned: failure or debug
  type: int
  sample: 200
url:
  description: The HTTP url used for the request to the APIC
  returned: failure or debug
  type: str
  sample: https://10.11.12.13/api/mo/uni/tn-production.json
"""


from ansible_collections.cisco.aci.plugins.module_utils.aci import ACIModule, aci_argument_spec, aci_annotation_spec
from ansible.module_utils.basic import AnsibleModule


def main():
    argument_spec = aci_argument_spec()
    argument_spec.update(aci_annotation_spec())
    argument_spec.update(
        name=dict(type="str", aliases=["syslog_group", "syslog_group_name"]),
        format=dict(type="str", choices=["aci", "nxos"]),
        admin_state=dict(type="str", choices=["enabled", "disabled"]),
        console_logging=dict(type="str", choices=["enabled", "disabled"]),
        console_log_severity=dict(type="str", choices=["alerts", "critical", "debugging", "emergencies", "error", "information", "notifications", "warnings"]),
        local_file_logging=dict(type="str", choices=["enabled", "disabled"]),
        local_file_log_severity=dict(
            type="str", choices=["alerts", "critical", "debugging", "emergencies", "error", "information", "notifications", "warnings"]
        ),
        include_ms=dict(type="bool"),
        include_time_zone=dict(type="bool"),
        state=dict(type="str", default="present", choices=["absent", "present", "query"]),
    )

    module = AnsibleModule(
        argument_spec=argument_spec,
        supports_check_mode=True,
        required_if=[
            ["state", "absent", ["name"]],
            ["state", "present", ["name"]],
        ],
    )

    aci = ACIModule(module)

    name = module.params.get("name")
    format = module.params.get("format")
    admin_state = module.params.get("admin_state")
    console_logging = module.params.get("console_logging")
    console_log_severity = module.params.get("console_log_severity")
    local_file_logging = module.params.get("local_file_logging")
    local_file_log_severity = module.params.get("local_file_log_severity")
    include_ms = aci.boolean(module.params.get("include_ms"))
    include_time_zone = aci.boolean(module.params.get("include_time_zone"))
    state = module.params.get("state")

    aci.construct_url(
        root_class=dict(
            aci_class="syslogGroup",
            aci_rn="fabric/slgroup-{0}".format(name),
            module_object=name,
            target_filter={"name": name},
        ),
        child_classes=["syslogRemoteDest", "syslogProf", "syslogFile", "syslogConsole"],
    )

    aci.get_existing()

    if state == "present":
        class_config = dict(
            name=name,
            format=format,
            includeMilliSeconds=include_ms,
        )
        if include_time_zone is not None:
            class_config["includeTimeZone"] = include_time_zone
        aci.payload(
            aci_class="syslogGroup",
            class_config=class_config,
            child_configs=[
                dict(
                    syslogProf=dict(
                        attributes=dict(adminState=admin_state, name="syslog"),
                    ),
                ),
                dict(
                    syslogFile=dict(
                        attributes=dict(adminState=local_file_logging, format=format, severity=local_file_log_severity),
                    ),
                ),
                dict(
                    syslogConsole=dict(
                        attributes=dict(adminState=console_logging, format=format, severity=console_log_severity),
                    ),
                ),
            ],
        )

        aci.get_diff(aci_class="syslogGroup")

        aci.post_config()

    elif state == "absent":
        aci.delete_config()

    aci.exit_json()


if __name__ == "__main__":
    main()



#!/usr/bin/python
# -*- coding: utf-8 -*-
# Copyright 2023 Red Hat
# GNU General Public License v3.0+
# (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

"""
The module file for ios_vxlan_vtep
"""

from __future__ import absolute_import, division, print_function


__metaclass__ = type

DOCUMENTATION = """
module: ios_vxlan_vtep
short_description: Resource module to configure VXLAN VTEP interface.
description: This module provides declarative management of VXLAN VTEP interface on Cisco IOS network
  devices.
version_added: 5.3.0
author: Padmini Priyadarshini Sivaraj (@PadminiSivaraj)
notes:
  - Tested against Cisco IOS-XE device with Version 17.13.01 on Cat9k on CML.
  - This module works with connection C(network_cli).
    See U(https://docs.ansible.com/ansible/latest/network/user_guide/platform_ios.html)
options:
  config:
    description: A dictionary of VXLAN VTEP interface option
    type: list
    elements: dict
    suboptions:
      interface:
        description:
        - VXLAN VTEP interface
        type: str
        required: true
      source_interface:
        description:
        - Source interface for the VXLAN VTEP interface
        type: str
      host_reachability_bgp:
        description:
        - Host reachability using EVPN protocol
        type: bool
      member:
        description:
        - Configure VNI member
        type: dict
        suboptions:
          vni:
            description:
            - Configure VNI information
            type: dict
            suboptions:
              l2vni:
                description:
                - Associates L2VNI with the VXLAN VTEP interface
                type: list
                elements: dict
                suboptions:
                  vni:
                    description: VNI number
                    type: int
                  replication:
                    description: Replication type for the L2VNI
                    type: dict
                    suboptions:
                      type:
                        description: Replication type
                        type: str
                        choices: ['ingress', 'static']
                      mcast_group:
                        description: Configure multicast group for VNI(s)
                        type: dict
                        suboptions:
                          ipv4:
                            description: IPv4 multicast group
                            type: str
                          ipv6:
                            description: IPv6 multicast group
                            type: str
              l3vni:
                description:
                - Associates L3VNI with the VXLAN VTEP interface
                type: list
                elements: dict
                suboptions:
                  vni:
                    description: VNI number
                    type: int
                  vrf:
                    description: VRF name of the L3VNI
                    type: str
  running_config:
    description:
      - This option is used only with state I(parsed).
      - The value of this option should be the output received from the IOS device by
        executing the command B(show running-config | section ^interface nve).
      - The state I(parsed) reads the configuration from C(running_config) option and
        transforms it into Ansible structured data as per the resource module's argspec
        and the value is then returned in the I(parsed) key within the result.
    type: str

  state:
    description:
      - The state the configuration should be left in
    type: str
    choices:
    - merged
    - replaced
    - overridden
    - deleted
    - rendered
    - gathered
    - parsed
    default: merged
"""

EXAMPLES = """

# Using state merged

# Before state:
# -------------
# interface nve1
#  no ip address
#  source-interface Loopback1
#  host-reachability protocol bgp
#  member vni 10101 mcast-group 225.0.0.101
#  member vni 10102 ingress-replication
#  member vni 50901 vrf green
#  member vni 10201 mcast-group 225.0.0.101
#  member vni 10202 ingress-replication
#  member vni 50902 vrf blue

# - name: Merge the provided configuration with the device configuration
#   cisco.ios.ios_vxlan_vtep:
#     config:
#     - interface: nve1
#       source_interface: loopback2
#       member:
#         vni:
#           l2vni:
#             - vni: 10101
#               replication:
#                 type: ingress
#             - vni: 10201
#               replication:
#                 type: static
#                 mcast_group:
#                   ipv4: 225.0.0.101
#                   ipv6: FF0E:225::101
#           l3vni:
#             - vni: 50901
#               vrf: blue
#     state: merged

# Commands Fired:
# ---------------
#   "commands": [
#         "interface nve1",
#         "source-interface loopback2",
#         "no member vni 10101 mcast-group 225.0.0.101",
#         "member vni 10101 ingress-replication",
#         "no member vni 10201 mcast-group 225.0.0.101",
#         "member vni 10201 mcast-group 225.0.0.101 FF0E:225::101",
#         "no member vni 50901 vrf green",
#         "no member vni 50902 vrf blue",
#         "member vni 50901 vrf blue"
#   ],

# After state:
# ------------
# interface nve1
#  no ip address
#  source-interface Loopback2
#  host-reachability protocol bgp
#  member vni 10102 ingress-replication
#  member vni 10202 ingress-replication
#  member vni 10101 ingress-replication
#  member vni 10201 mcast-group 225.0.0.101 FF0E:225::101
#  member vni 50901 vrf blue

# Using state replaced

# Before state:
# -------------
# interface nve1
#  no ip address
#  source-interface Loopback2
#  host-reachability protocol bgp
#  member vni 10102 ingress-replication
#  member vni 10202 ingress-replication
#  member vni 10101 ingress-replication
#  member vni 10201 mcast-group 225.0.0.101 FF0E:225::101
#  member vni 50901 vrf blue

# - name: Replaces the device configuration with the provided configuration
#   cisco.ios.ios_vxlan_vtep:
#     config:
#     - interface: nve1
#       source_interface: Loopback2
#       member:
#         vni:
#           l2vni:
#             - vni: 10101
#               replication:
#                 type: static
#                 mcast_group:
#                   ipv6: FF0E:225::101
#             - vni: 10201
#               replication:
#                 type: static
#                 mcast_group:
#                   ipv6: FF0E:225::102
#     state: replaced

# Commands Fired:
# ---------------
#   "commands": [
#       "interface nve1",
#       "no member vni 10101 ingress-replication",
#       "member vni 10101 mcast-group FF0E:225::101",
#       "no member vni 10201 mcast-group 225.0.0.101 FF0E:225::101",
#       "member vni 10201 mcast-group FF0E:225::102",
#       "no member vni 10102 ingress-replication",
#       "no member vni 10202 ingress-replication",
#       "no member vni 50901 vrf blue"
#   ],

# After state:
# ------------
# interface nve1
#  no ip address
#  source-interface Loopback2
#  host-reachability protocol bgp
#  member vni 10101 mcast-group FF0E:225::101
#  member vni 10201 mcast-group FF0E:225::102

# Using state Deleted

# Before state:
# -------------
# interface nve1
#  no ip address
#  source-interface Loopback2
#  host-reachability protocol bgp
#  member vni 10101 mcast-group FF0E:225::101
#  member vni 10201 mcast-group FF0E:225::102

# - name: "Delete VXLAN VTEP interface"
#   cisco.ios.ios_vxlan_vtep:
#     config:
#     - interface: nve1
#     state: deleted

# Commands Fired:
# ---------------
#   "commands": [
#       "interface nve1",
#       "no source-interface Loopback2",
#       "no host-reachability protocol bgp",
#       "no member vni 10101 mcast-group FF0E:225::101",
#       "no member vni 10201 mcast-group FF0E:225::102"
#   ],

# After state:
# -------------
# interface nve1
#  no ip address

# Using state Deleted with member VNIs

# Before state:
# -------------
# interface nve1
#  no ip address
#  source-interface Loopback2
#  host-reachability protocol bgp
#  member vni 10101 mcast-group FF0E:225::101
#  member vni 10102 mcast-group 225.0.0.101
#  member vni 10201 mcast-group 225.0.0.101 FF0E:225::101

# - name: "Delete VXLAN VTEP interface with member VNIs"
#   cisco.ios.ios_vxlan_vtep:
#     config:
#     - interface: nve1
#       source_interface: Loopback2
#       member:
#         vni:
#           l2vni:
#             - vni: 10101
#             - vni: 10102
#     state: deleted

# Commands Fired:
# ---------------
#   "commands": [
#       "interface nve1",
#       "no member vni 10101 mcast-group FF0E:225::101",
#       "no member vni 10102 mcast-group 225.0.0.101"
#   ],

# After state:
# -------------
# interface nve1
#  no ip address
#  source-interface Loopback2
#  host-reachability protocol bgp
#  member vni 10201 mcast-group 225.0.0.101 FF0E:225::101

# Using state Deleted with no config

# Before state:
# -------------
# interface nve1
#  no ip address
#  source-interface Loopback2
#  host-reachability protocol bgp
#  member vni 10101 mcast-group FF0E:225::101
#  member vni 10201 mcast-group FF0E:225::102

# - name: "Delete VXLAN VTEP interface with no config"
#   cisco.ios.ios_vxlan_vtep:
#     state: deleted

# Commands Fired:
# ---------------
#   "commands": [
#       "interface nve1",
#       "no source-interface Loopback2",
#       "no host-reachability protocol bgp",
#       "no member vni 10101 mcast-group FF0E:225::101",
#       "no member vni 10201 mcast-group FF0E:225::102"
#   ],

# After state:
# -------------
# interface nve1
#  no ip address
"""

RETURN = """
before:
  description: The configuration prior to the module execution.
  returned: when I(state) is C(merged), C(replaced), C(overridden), C(deleted) or C(purged)
  type: dict
  sample: >
    This output will always be in the same format as the
    module argspec.
after:
  description: The resulting configuration after module execution.
  returned: when changed
  type: dict
  sample: >
    This output will always be in the same format as the
    module argspec.
commands:
  description: The set of commands pushed to the remote device.
  returned: when I(state) is C(merged), C(replaced), C(overridden), C(deleted) or C(purged)
  type: list
  sample:
    - 'interface nve1'
    - 'source-interface Loopback1'
    - 'host-reachability protocol bgp'
    - 'member vni 10101 ingress-replication'
"""

from ansible.module_utils.basic import AnsibleModule

from ansible_collections.cisco.ios.plugins.module_utils.network.ios.argspec.vxlan_vtep.vxlan_vtep import (
    Vxlan_vtepArgs,
)
from ansible_collections.cisco.ios.plugins.module_utils.network.ios.config.vxlan_vtep.vxlan_vtep import (
    Vxlan_vtep,
)


def main():
    """
    Main entry point for module execution

    :returns: the result form module invocation
    """
    module = AnsibleModule(
        argument_spec=Vxlan_vtepArgs.argument_spec,
        mutually_exclusive=[["config", "running_config"]],
        required_if=[
            ["state", "merged", ["config"]],
            ["state", "replaced", ["config"]],
            ["state", "overridden", ["config"]],
            ["state", "rendered", ["config"]],
            ["state", "parsed", ["running_config"]],
        ],
        supports_check_mode=True,
    )

    result = Vxlan_vtep(module).execute_module()
    module.exit_json(**result)


if __name__ == "__main__":
    main()



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright: Contributors to the Ansible project
# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: ec2_eni_info
version_added: 1.0.0
short_description: Gather information about EC2 ENI interfaces in AWS
description:
  - Gather information about EC2 ENI interfaces in AWS.
author:
  - "Rob White (@wimnat)"
options:
  eni_id:
    description:
      - The ID of the ENI.
      - This option is mutually exclusive of O(filters).
    type: str
    version_added: 1.3.0
  filters:
    description:
      - A dict of filters to apply. Each dict item consists of a filter key and a filter value.
        See U(https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeNetworkInterfaces.html) for possible filters.
      - This option is mutually exclusive of O(eni_id).
    type: dict
    default: {}
extends_documentation_fragment:
  - amazon.aws.common.modules
  - amazon.aws.region.modules
  - amazon.aws.boto3
"""

EXAMPLES = r"""
# Note: These examples do not set authentication details, see the AWS Guide for details.

# Gather information about all ENIs
- amazon.aws.ec2_eni_info:

# Gather information about a particular ENI
- amazon.aws.ec2_eni_info:
    filters:
      network-interface-id: eni-xxxxxxx
"""

RETURN = r"""
network_interfaces:
  description: List of matching elastic network interfaces.
  returned: always
  type: complex
  contains:
    association:
      description: Info of associated elastic IP (EIP).
      returned: When an ENI is associated with an EIP
      type: dict
      sample: {
          allocation_id: "eipalloc-5sdf123",
          association_id: "eipassoc-8sdf123",
          ip_owner_id: "123456789012",
          public_dns_name: "ec2-52-1-0-63.compute-1.amazonaws.com",
          public_ip: "52.1.0.63"
        }
    attachment:
      description: Info about attached ec2 instance.
      returned: When an ENI is attached to an ec2 instance
      type: dict
      sample: {
        attach_time: "2017-08-05T15:25:47+00:00",
        attachment_id: "eni-attach-149d21234",
        delete_on_termination: false,
        device_index: 1,
        instance_id: "i-15b8d3cadbafa1234",
        instance_owner_id: "123456789012",
        "network_card_index": 0,
        status: "attached"
      }
    availability_zone:
      description: Availability zone of ENI.
      returned: always
      type: str
      sample: "us-east-1b"
    description:
      description: Description text for ENI.
      returned: always
      type: str
      sample: "My favourite network interface"
    groups:
      description: List of attached security groups.
      returned: always
      type: list
      sample: [
        {
          group_id: "sg-26d0f1234",
          group_name: "my_ec2_security_group"
        }
      ]
    id:
      description: The id of the ENI (alias for RV(network_interfaces.network_interface_id)).
      returned: always
      type: str
      sample: "eni-392fsdf"
    interface_type:
      description: Type of the network interface.
      returned: always
      type: str
      sample: "interface"
    ipv6_addresses:
      description: List of IPv6 addresses for this interface.
      returned: always
      type: list
      sample: []
    mac_address:
      description: MAC address of the network interface.
      returned: always
      type: str
      sample: "0a:f8:10:2f:ab:a1"
    name:
      description: The Name tag of the ENI, often displayed in the AWS UIs as Name.
      returned: When a Name tag has been set
      type: str
      version_added: 1.3.0
    network_interface_id:
      description: The id of the ENI.
      returned: always
      type: str
      sample: "eni-392fsdf"
    owner_id:
      description: AWS account id of the owner of the ENI.
      returned: always
      type: str
      sample: "123456789012"
    private_dns_name:
      description: Private DNS name for the ENI.
      returned: always
      type: str
      sample: "ip-172-16-1-180.ec2.internal"
    private_ip_address:
      description: Private IP address for the ENI.
      returned: always
      type: str
      sample: "172.16.1.180"
    private_ip_addresses:
      description: List of private IP addresses attached to the ENI.
      returned: always
      type: list
      sample: []
    requester_id:
      description: The ID of the entity that launched the ENI.
      type: str
      sample: "AIDA12345EXAMPLE54321"
    requester_managed:
      description:  Indicates whether the network interface is being managed by an AWS service.
      returned: always
      type: bool
      sample: false
    source_dest_check:
      description: Indicates whether the network interface performs source/destination checking.
      returned: always
      type: bool
      sample: false
    status:
      description: Indicates if the network interface is attached to an instance or not.
      returned: always
      type: str
      sample: "in-use"
    subnet_id:
      description: Subnet ID the ENI is in.
      returned: always
      type: str
      sample: "subnet-7bbf01234"
    tags:
      description: Dictionary of tags added to the ENI.
      returned: always
      type: dict
      sample: {}
      version_added: 1.3.0
    tag_set:
      description: Dictionary of tags added to the ENI.
      returned: always
      type: dict
      sample: {}
    vpc_id:
      description: ID of the VPC the network interface it part of.
      returned: always
      type: str
      sample: "vpc-b3f1f123"
"""

from typing import Any
from typing import Dict
from typing import List

from ansible.module_utils.common.dict_transformations import camel_dict_to_snake_dict

from ansible_collections.amazon.aws.plugins.module_utils.ec2 import AnsibleEC2Error
from ansible_collections.amazon.aws.plugins.module_utils.ec2 import describe_network_interfaces
from ansible_collections.amazon.aws.plugins.module_utils.modules import AnsibleAWSModule
from ansible_collections.amazon.aws.plugins.module_utils.tagging import boto3_tag_list_to_ansible_dict
from ansible_collections.amazon.aws.plugins.module_utils.transformation import ansible_dict_to_boto3_filter_list


def build_request_args(eni_id, filters):
    request_args = {
        "NetworkInterfaceIds": [eni_id] if eni_id else [],
        "Filters": ansible_dict_to_boto3_filter_list(filters),
    }

    request_args = {k: v for k, v in request_args.items() if v}

    return request_args


def get_network_interfaces(connection, module: AnsibleAWSModule, request_args: Dict[str, Any]) -> List[Dict[str, Any]]:
    try:
        network_interfaces_result = describe_network_interfaces(connection, **request_args)
        if not network_interfaces_result:
            module.exit_json(network_interfaces=[])
    except AnsibleEC2Error as e:
        module.fail_json_aws(e)

    return network_interfaces_result


def list_eni(connection, module: AnsibleAWSModule, request_args: Dict[str, Any]) -> List[Dict[str, Any]]:
    network_interfaces_result = get_network_interfaces(connection, module, request_args)

    # Modify boto3 tags list to be ansible friendly dict and then camel_case
    camel_network_interfaces = []
    for network_interface in network_interfaces_result:
        network_interface["TagSet"] = boto3_tag_list_to_ansible_dict(network_interface["TagSet"])
        network_interface["Tags"] = network_interface["TagSet"]
        if "Name" in network_interface["Tags"]:
            network_interface["Name"] = network_interface["Tags"]["Name"]
        # Added id to interface info to be compatible with return values of ec2_eni module:
        network_interface["Id"] = network_interface["NetworkInterfaceId"]
        camel_network_interfaces.append(camel_dict_to_snake_dict(network_interface, ignore_list=["Tags", "TagSet"]))

    return camel_network_interfaces


def main():
    argument_spec = dict(
        eni_id=dict(type="str"),
        filters=dict(default={}, type="dict"),
    )
    mutually_exclusive = [
        ["eni_id", "filters"],
    ]

    module = AnsibleAWSModule(
        argument_spec=argument_spec,
        supports_check_mode=True,
        mutually_exclusive=mutually_exclusive,
    )

    connection = module.client("ec2")

    request_args = build_request_args(
        eni_id=module.params["eni_id"],
        filters=module.params["filters"],
    )

    result = list_eni(connection, module, request_args)

    module.exit_json(network_interfaces=result)


if __name__ == "__main__":
    main()



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: system_certificate_export_info
short_description: Information module for System Certificate Export Info
description:
- Get System Certificate Export Info.
- Export System Certificate.
version_added: '1.0.0'
extends_documentation_fragment:
  - cisco.ise.module_info
author: Rafael Campos (@racampos)
options:
  dirPath:
    description: Directory absolute path. Defaults to the current working directory.
    type: str
  export:
    description: System Certificate Export Info's export.
    type: str
  filename:
    description: The filename used to save the download file.
    type: str
  hostName:
    description: Hostname of the Cisco ISE node in which self-signed certificate should
      be generated.
    type: str
  id:
    description: System Certificate Export Info's id.
    type: str
  password:
    description: System Certificate Export Info's password.
    type: str
  saveFile:
    description: Enable or disable automatic file creation of raw response.
    type: bool
requirements:
- ciscoisesdk >= 2.2.3
- python >= 3.5
seealso:
- name: Cisco ISE documentation for Certificates
  description: Complete reference of the Certificates API.
  link: https://developer.cisco.com/docs/identity-services-engine/v1/#!certificate-openapi
notes:
  - SDK Method used are
    certificates.Certificates.export_system_certificate,

  - Paths used are

"""

EXAMPLES = r"""
- name: Create
  cisco.ise.system_certificate_export_info:
    ise_hostname: "{{ise_hostname}}"
    ise_username: "{{ise_username}}"
    ise_password: "{{ise_password}}"
    ise_verify: "{{ise_verify}}"
    dirPath: /tmp/downloads/
    export: string
    filename: download_filename.extension
    hostName: string
    id: string
    password: string
    saveFile: true

"""

RETURN = r"""
ise_response:
  description: A dictionary or list with the response returned by the Cisco ISE Python SDK
  returned: always
  type: dict
  sample: >
    {
      "description": "string",
      "file": "string",
      "filename": "string",
      "inputStream": {},
      "open": true,
      "readable": true,
      "uri": "string",
      "url": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: license_device_license_details_v1_info
short_description: Information module for License Device License Details V1
description:
- Get all License Device License Details V1.
- Get detailed license information of a device.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  device_uuid:
    description:
    - Device_uuid path parameter. Id of device.
    type: str
requirements:
- dnacentersdk >= 2.4.9
- python >= 3.5
seealso:
- name: Cisco DNA Center documentation for Licenses DeviceLicenseDetailsV1
  description: Complete reference of the DeviceLicenseDetailsV1 API.
  link: https://developer.cisco.com/docs/dna-center/#!device-license-details
notes:
  - SDK Method used are
    licenses.Licenses.device_license_details_v1,

  - Paths used are
    get /dna/intent/api/v1/licenses/device/{device_uuid}/details,

"""

EXAMPLES = r"""
- name: Get all License Device License Details V1
  cisco.dnac.license_device_license_details_v1_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    device_uuid: string
  register: result

"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "device_uuid": "string",
      "site": "string",
      "model": "string",
      "license_mode": "string",
      "is_license_expired": true,
      "software_version": "string",
      "network_license": "string",
      "evaluation_license_expiry": "string",
      "device_name": "string",
      "device_type": "string",
      "dna_level": "string",
      "virtual_account_name": "string",
      "ip_address": "string",
      "mac_address": "string",
      "sntc_status": "string",
      "feature_license": [
        "string"
      ],
      "has_sup_cards": true,
      "udi": "string",
      "stacked_devices": [
        {
          "mac_address": "string",
          "id": 0,
          "role": "string",
          "serial_number": "string"
        }
      ],
      "is_stacked_device": true,
      "access_points": [
        {
          "ap_type": "string",
          "count": "string"
        }
      ],
      "chassis_details": {
        "board_serial_number": "string",
        "modules": [
          {
            "module_type": "string",
            "module_name": "string",
            "serial_number": "string",
            "id": 0
          }
        ],
        "supervisor_cards": [
          {
            "serial_number": "string",
            "supervisor_card_type": "string",
            "status": "string"
          }
        ],
        "port": 0
      }
    }
"""



# -*- coding: utf-8 -*-
# Copyright 2022 Red Hat
# GNU General Public License v3.0+
# (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

from __future__ import absolute_import, division, print_function


__metaclass__ = type

"""
The Lag_interfaces parser templates file. This contains
a list of parser definitions and associated functions that
facilitates both facts gathering and native command generation for
the given network resource.
"""

import re

from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.rm_base.network_template import (
    NetworkTemplate,
)


class Lag_interfacesTemplate(NetworkTemplate):
    def __init__(self, lines=None, module=None):
        super(Lag_interfacesTemplate, self).__init__(lines=lines, tmplt=self, module=module)

    # fmt: off
    PARSERS = [
        {
            'name': 'member',
            'getval': re.compile(
                r'''
              ^interface\s
              (?P<member>\S+)$''', re.VERBOSE,
            ),
            'setval': 'interface {{ member }}',
            'result': {
                '{{ member }}': {
                    'member': '{{ member }}',
                },
            },
            'shared': True,
        },
        {
            "name": "channel",
            "getval": re.compile(
                r"""
                \s+channel-group
                (\s(?P<channel>\d+))?
                (\smode\s(?P<mode>active|passive|on|desirable|auto))?
                (\slink\s(?P<link>\d+))?
                $""", re.VERBOSE,
            ),
            "setval": "channel-group"
            "{{ (' ' + channel|string) if channel is defined else '' }}"
            "{{ (' mode ' + mode) if mode is defined else '' }}"
            "{{ (' link ' + link|string) if link is defined else '' }}",
            "result": {
                '{{ member }}': {
                    'member': '{{ member }}',
                    'mode': '{{ mode }}',
                    'channel': 'Port-channel{{ channel }}',
                    'link': '{{ link }}',
                },
            },
        },
    ]
    # fmt: on



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: interfaces_query_v1
short_description: Resource module for Interfaces Query V1
description:
- Manage operation create of the resource Interfaces Query V1.
- >
   Gets the list of interfaces across the Network Devices based on the provided complex filters and aggregation
   functions.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  aggregateAttributes:
    description: Interfaces Query's aggregateAttributes.
    elements: dict
    suboptions:
      function:
        description: Function.
        type: str
      name:
        description: Name.
        type: str
    type: list
  attributes:
    description: Attributes.
    elements: str
    type: list
  endTime:
    description: End Time.
    type: int
  filters:
    description: Interfaces Query's filters.
    elements: dict
    suboptions:
      filters:
        description: Interfaces Query's filters.
        elements: dict
        suboptions:
          filters:
            description: Filters.
            elements: str
            type: list
          key:
            description: Key.
            type: str
          logicalOperator:
            description: Logical Operator.
            type: str
          operator:
            description: Operator.
            type: str
          value:
            description: Value.
            type: dict
        type: list
      key:
        description: Key.
        type: str
      logicalOperator:
        description: Logical Operator.
        type: str
      operator:
        description: Operator.
        type: str
      value:
        description: Value.
        type: dict
    type: list
  page:
    description: Interfaces Query's page.
    suboptions:
      limit:
        description: Limit.
        type: int
      offset:
        description: Offset.
        type: int
      sortBy:
        description: Interfaces Query's sortBy.
        elements: dict
        suboptions:
          name:
            description: Name.
            type: str
          order:
            description: Order.
            type: str
        type: list
    type: dict
  startTime:
    description: Start Time.
    type: int
  views:
    description: Views.
    elements: str
    type: list
requirements:
- dnacentersdk >= 2.4.9
- python >= 3.5
seealso:
- name: Cisco DNA Center documentation for Devices GetsTheListOfInterfacesAcrossTheNetworkDevicesBasedOnTheProvidedComplexFiltersAndAggregationFunctionsV1 # noqa: E501
  description: Complete reference of the GetsTheListOfInterfacesAcrossTheNetworkDevicesBasedOnTheProvidedComplexFiltersAndAggregationFunctionsV1 API.   # noqa: E501
  link: https://developer.cisco.com/docs/dna-center/#!gets-the-list-of-interfaces-across-the-network-devices-based-on-the-provided-complex-filters-and-aggregation-functions  # noqa: E501
notes:
  - SDK Method used are
    devices.Devices.gets_the_list_of_interfaces_across_the_network_devices_based_on_the_provided_complex_filters_and_aggregation_functions_v1,  # noqa: E501

  - Paths used are
    post /dna/data/api/v1/interfaces/query,

"""

EXAMPLES = r"""
- name: Create
  cisco.dnac.interfaces_query_v1:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    aggregateAttributes:
    - function: string
      name: string
    attributes:
    - string
    endTime: 0
    filters:
    - filters:
      - filters:
        - string
        key: string
        logicalOperator: string
        operator: string
        value: {}
      key: string
      logicalOperator: string
      operator: string
      value: {}
    page:
      limit: 0
      offset: 0
      sortBy:
      - name: string
        order: string
    startTime: 0
    views:
    - string

"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "adminStatus": "string",
          "description": "string",
          "duplexConfig": "string",
          "duplexOper": "string",
          "interfaceIfIndex": 0,
          "interfaceType": "string",
          "ipv4Address": "string",
          "ipv6AddressList": [
            "string"
          ],
          "isL3Interface": true,
          "isWan": true,
          "macAddr": "string",
          "mediaType": "string",
          "name": "string",
          "operStatus": "string",
          "peerStackMember": 0,
          "peerStackPort": "string",
          "portChannelId": "string",
          "portMode": "string",
          "portType": "string",
          "rxDiscards": 0,
          "rxError": 0,
          "rxRate": 0,
          "rxUtilization": 0,
          "speed": "string",
          "stackPortType": "string",
          "timestamp": 0,
          "txDiscards": 0,
          "txError": 0,
          "txRate": 0,
          "txUtilization": 0,
          "vlanId": "string",
          "networkDeviceId": "string",
          "networkDeviceIpAddress": "string",
          "networkDeviceMacAddress": "string",
          "siteName": "string",
          "siteHierarchy": "string",
          "siteHierarchyId": "string",
          "aggregateAttributes": [
            {
              "name": "string",
              "values": [
                {
                  "key": "string",
                  "value": 0
                }
              ]
            }
          ]
        }
      ],
      "page": {
        "limit": 0,
        "offset": 0,
        "count": 0,
        "sortBy": [
          {
            "name": "string",
            "order": "string"
          }
        ]
      },
      "version": "string"
    }
"""



#!/usr/bin/python
#
# Copyright (c) 2023 xuzhang3 (@xuzhang3), Fred-sun (@Fred-sun)
#
# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

from __future__ import absolute_import, division, print_function
__metaclass__ = type


DOCUMENTATION = '''
---
module: azure_rm_sshpublickey_info

version_added: "2.0.0"

short_description: Get Ssh Public Key with VM facts

description:
    - Get Ssh Public Key with VM facts

options:
    resource_group:
        description:
            - Name of the resource group.
        type: str
    name:
        description:
            - Name of the SSH Public Key.
        type: str
    tags:
        description:
            - Limit results by providing a list of tags. Format tags as 'key' or 'key:value'.
        type: list
        elements: str

extends_documentation_fragment:
    - azure.azcollection.azure

author:
    - xuzhang3 (@xuzhang3)
    - Fred-sun (@Fred-sun)

'''

EXAMPLES = '''
- name: Get facts of the VM's ssh public key by name
  azure_rm_sshpublickey_info:
    resource_group: myResourceGroup
    name: mysshpublickey

- name: Get facts of the VM's ssh public key by resource group
  azure_rm_sshpublickey_info:
    resource_group: myResourceGroup

- name: Get facts by tags
  azure_rm_sshpublickey_info:
    resource_group: myResourceGroup
    tags:
      - testing
      - foo:bar
'''

RETURN = '''
ssh_keys:
    description:
        - Current state of the SSH Public Key.
    returned: always
    type: complex
    contains:
        id:
            description:
                - Resource ID.
            returned: always
            type: str
            sample: /subscriptions/xxxx/resourceGroups/xxx/providers/Microsoft.Compute/sshPublicKeys/mySshPublicKeyName
        location:
            description:
                - The Geo-location where the resource lives.
            returned: always
            type: str
            sample: eastus
        name:
            description:
                - Resource name.
            returned: always
            type: str
            sample: mySshPublicKey
        tags:
            description:
                - Resource tags, such as { 'tags1':'value1' }.
            returned: always
            type: dict
            sample: { 'key1':'value1' }
        public_key:
            description:
                - SSH public key used to authenticate to a virtual machine through ssh.
            returned: always
            type: str
            sample: "ssh-rsa **************@test.com"
'''

try:
    from azure.core.exceptions import ResourceNotFoundError
except Exception:
    # This is handled in azure_rm_common
    pass

from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common import AzureRMModuleBase


class AzureRMSshPublicKeyInfo(AzureRMModuleBase):

    def __init__(self):

        self.module_arg_spec = dict(
            resource_group=dict(type='str'),
            name=dict(type='str'),
            tags=dict(type='list', elements='str')
        )

        self.results = dict(
            changed=False,
            ssh_keys=[]
        )

        self.resource_group = None
        self.name = None
        self.tags = None

        super(AzureRMSshPublicKeyInfo, self).__init__(self.module_arg_spec,
                                                      supports_check_mode=True,
                                                      supports_tags=False,
                                                      facts_module=True)

    def exec_module(self, **kwargs):
        for key in self.module_arg_spec:
            setattr(self, key, kwargs[key])

        if self.name and self.resource_group:
            response = [self.get_by_name()]
        elif self.resource_group:
            response = self.list_by_resourcegroup()
        else:
            response = self.list_all()

        self.results['ssh_keys'] = [self.to_dict(item) for item in response if response is not None]

        return self.results

    def get_by_name(self):
        response = None
        try:
            response = self.compute_client.ssh_public_keys.get(self.resource_group, self.name)

        except ResourceNotFoundError as exec:
            self.log("Failed to get ssh public keys, Exception as {0}".format(exec))

        return response

    def list_by_resourcegroup(self):
        response = None
        try:
            response = self.compute_client.ssh_public_keys.list_by_resource_group(self.resource_group)
        except Exception as exec:
            self.log("Faild to list ssh public keys by resource group, exception as {0}".format(exec))
        return response

    def list_all(self):
        response = None
        try:
            response = self.compute_client.ssh_public_keys.list_by_subscription()
        except Exception as exc:
            self.fail("Failed to list all items - {0}".format(str(exc)))

        return response

    def to_dict(self, body):
        results = dict()
        if body is not None and self.has_tags(body.tags, self.tags):
            results = dict(
                id=body.id,
                name=body.name,
                location=body.location,
                tags=body.tags,
                public_key=body.public_key
            )
        return results


def main():
    AzureRMSshPublicKeyInfo()


if __name__ == '__main__':
    main()



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)


DOCUMENTATION = r"""
---
module: sites_device_credentials_apply
short_description: Resource module for Sites Device Credentials Apply
description:
- This module represents an alias of the module sites_device_credentials_apply_v1
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  deviceCredentialId:
    description: It must be cli/snmpV2Read/snmpV2Write/snmpV3 Id.
    type: str
  siteId:
    description: Site Id.
    type: str
requirements:
- dnacentersdk >= 2.4.9
- python >= 3.5
seealso:
- name: Cisco DNA Center documentation for Network Settings SyncNetworkDevicesCredentialV1
  description: Complete reference of the SyncNetworkDevicesCredentialV1 API.
  link: https://developer.cisco.com/docs/dna-center/#!sync-network-devices-credential
notes:
  - SDK Method used are
    network_settings.NetworkSettings.sync_network_devices_credential_v1,

  - Paths used are
    post /dna/intent/api/v1/sites/deviceCredentials/apply,
  - It should be noted that this module is an alias of sites_device_credentials_apply_v1

"""

EXAMPLES = r"""
- name: Create
  cisco.dnac.sites_device_credentials_apply:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    deviceCredentialId: string
    siteId: string

"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "version": "string",
      "response": {
        "url": "string",
        "taskId": "string"
      }
    }
"""



# -*- coding: utf-8 -*-
# Copyright 2020 Red Hat
# GNU General Public License v3.0+
# (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)


"""
The get_path lookup plugin
"""
from __future__ import absolute_import, division, print_function


__metaclass__ = type


DOCUMENTATION = """
    name: get_path
    author: Bradley Thornton (@cidrblock)
    version_added: "1.0.0"
    short_description: Retrieve the value in a variable using a path
    description:
      - Use a I(path) to retrieve a nested value from a I(var)
      - B(get_path) is also available as a B(filter plugin) for convenience
      - Using the parameters below- C(lookup('ansible.utils.get_path', var, path, wantlist))
    options:
      var:
        description:
          - The variable from which the value should be extracted.
        type: raw
        required: True
      path:
        description:
          - The I(path) in the I(var) to retrieve the value of.
          - The I(path) needs to a be a valid jinja path.
        type: str
        required: True
      wantlist:
        description:
          - If set to C(True), the return value will always be a list.
          - This can also be accomplished using C(query) or C(q) instead of C(lookup).
          - U(https://docs.ansible.com/ansible/latest/plugins/lookup.html).
        type: bool

    notes:
"""

EXAMPLES = r"""
- ansible.builtin.set_fact:
    a:
      b:
        c:
          d:
            - 0
            - 1
          e:
            - true
            - false

- name: Retrieve a value deep inside a using a path
  ansible.builtin.set_fact:
    value: "{{ lookup('ansible.utils.get_path', a, path) }}"
  vars:
    path: b.c.d[0]

# TASK [Retrieve a value deep inside a using a path] ******************
# ok: [localhost] => changed=false
#   ansible_facts:
#     value: '0'


#### Working with hostvars

- name: Retrieve a value deep inside all of the host's vars
  ansible.builtin.set_fact:
    value: "{{ lookup('ansible.utils.get_path', look_in, look_for) }}"
  vars:
    look_in: "{{ hostvars[inventory_hostname] }}"
    look_for: a.b.c.d[0]

# TASK [Retrieve a value deep inside all of the host's vars] ********
# ok: [nxos101] => changed=false
#   ansible_facts:
#     as_filter: '0'
#     as_lookup: '0'


#### Used alongside ansible.utils.to_paths

- name: Get the paths for the object
  ansible.builtin.set_fact:
    paths: "{{ lookup('ansible.utils.to_paths', a, prepend='a') }}"

- name: Retrieve the value of each path from vars
  ansible.builtin.debug:
    msg: "The value of path {{ path }} in vars is {{ value }}"
  loop: "{{ paths.keys()|list }}"
  loop_control:
    label: "{{ item }}"
  vars:
    path: "{{ item }}"
    value: "{{ lookup('ansible.utils.get_path', hostvars[inventory_hostname], item) }}"

# TASK [Get the paths for the object] *******************************
# ok: [nxos101] => changed=false
#   ansible_facts:
#     paths:
#       a.b.c.d[0]: 0
#       a.b.c.d[1]: 1
#       a.b.c.e[0]: True
#       a.b.c.e[1]: False

# TASK [Retrieve the value of each path from vars] ******************
# ok: [nxos101] => (item=a.b.c.d[0]) =>
#   msg: The value of path a.b.c.d[0] in vars is 0
# ok: [nxos101] => (item=a.b.c.d[1]) =>
#   msg: The value of path a.b.c.d[1] in vars is 1
# ok: [nxos101] => (item=a.b.c.e[0]) =>
#   msg: The value of path a.b.c.e[0] in vars is True
# ok: [nxos101] => (item=a.b.c.e[1]) =>
#   msg: The value of path a.b.c.e[1] in vars is False


#### Working with complex structures and transforming results

- name: Retrieve the current interface config
  cisco.nxos.nxos_interfaces:
    state: gathered
  register: interfaces

- name: Get the description of several interfaces
  ansible.builtin.debug:
    msg: "{{ lookup('ansible.utils.get_path', rekeyed, item) }}"
  vars:
    rekeyed:
      by_name: "{{ interfaces.gathered|ansible.builtin.rekey_on_member('name') }}"
  loop:
    - by_name['Ethernet1/1'].description
    - by_name['Ethernet1/2'].description|upper
    - by_name['Ethernet1/3'].description|default('')


# TASK [Get the description of several interfaces] ******************
# ok: [nxos101] => (item=by_name['Ethernet1/1'].description) => changed=false
#   msg: Configured by ansible
# ok: [nxos101] => (item=by_name['Ethernet1/2'].description|upper) => changed=false
#   msg: CONFIGURED BY ANSIBLE
# ok: [nxos101] => (item=by_name['Ethernet1/3'].description|default('')) => changed=false
#   msg: ''
"""

RETURN = """
  _raw:
    description:
      - One or more zero-based indices of the matching list items.
      - See C(wantlist) if a list is always required.
"""

from ansible.errors import AnsibleLookupError
from ansible.plugins.lookup import LookupBase

from ansible_collections.ansible.utils.plugins.module_utils.common.argspec_validate import (
    AnsibleArgSpecValidator,
)
from ansible_collections.ansible.utils.plugins.module_utils.common.get_path import get_path


class LookupModule(LookupBase):
    def run(self, terms, variables, **kwargs):
        if isinstance(terms, list):
            keys = ["var", "path"]
            terms = dict(zip(keys, terms))
        terms.update(kwargs)

        aav = AnsibleArgSpecValidator(data=terms, schema=DOCUMENTATION, name="get_path")
        valid, errors, updated_data = aav.validate()
        if not valid:
            raise AnsibleLookupError(errors)
        updated_data["wantlist"] = True
        updated_data["environment"] = self._templar.environment
        res = get_path(**updated_data)
        return res



# -*- coding: utf-8 -*-
# Copyright 2024 Red Hat
# GNU General Public License v3.0+
# (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
#

from __future__ import absolute_import, division, print_function


__metaclass__ = type

"""
The ios_vrf_global config file.
It is in this file where the current configuration (as dict)
is compared to the provided configuration (as dict) and the command set
necessary to bring the current configuration to its desired end-state is
created.
"""

from ansible.module_utils.six import iteritems
from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.rm_base.resource_module import (
    ResourceModule,
)
from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.utils import (
    dict_merge,
)

from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.facts import Facts
from ansible_collections.cisco.ios.plugins.module_utils.network.ios.rm_templates.vrf_global import (
    Vrf_globalTemplate,
)


class Vrf_global(ResourceModule):
    """
    The ios_vrf_global config class
    """

    def __init__(self, module):
        super(Vrf_global, self).__init__(
            empty_fact_val={},
            facts_module=Facts(module),
            module=module,
            resource="vrf_global",
            tmplt=Vrf_globalTemplate(),
        )
        self.parsers = [
            "description",
            "ipv4.multicast.multitopology",
            "ipv6.multicast.multitopology",
            "rd",
            "route_target.export",
            "route_target.import_config",
            "route_target.both",
            "vnet.tag",
            "vpn.id",
        ]

    def execute_module(self):
        """Execute the module

        :rtype: A dictionary
        :returns: The result from module execution
        """
        if self.state not in ["parsed", "gathered"]:
            self.generate_commands()
            self.run_commands()
        return self.result

    def generate_commands(self):
        """Generate configuration commands to send based on
        want, have and desired state.
        """
        haved, wantd = dict(), dict()

        if self.want:
            for entry in self.want.get("vrfs", []):
                wantd.update({(entry["name"]): entry})

        if self.have:
            for entry in self.have.get("vrfs", []):
                haved.update({(entry["name"]): entry})

        # if state is merged, merge want onto have
        if self.state == "merged":
            wantd = dict_merge(haved, wantd)

        # if state is deleted, limit the have to anything in want & set want to nothing
        if self.state == "deleted":
            haved = {k: v for k, v in iteritems(haved) if k in wantd or not wantd}
            wantd = {}

        if self.state in ["overridden", "deleted"]:
            for k, have in iteritems(haved):
                if k not in wantd:
                    self._compare(want={}, have=have)

        if self.state == "purged":
            for k, have in iteritems(haved):
                self.purge(have)

        for k, want in iteritems(wantd):
            self._compare(want=want, have=haved.pop(k, {}))

    def _compare(self, want, have):
        """Leverages the base class `compare()` method and
        populates the list of commands to be run by comparing
        the `want` and `have` data with the `parsers` defined
        for the Vrf_global network resource.
        """
        if want != have:
            self.addcmd(want or have, "name", False)
            self.compare(self.parsers, want, have)

    def purge(self, have):
        """Purge the VRF configuration"""
        self.commands.append("no vrf definition {0}".format(have["name"]))



# (c) 2018 Yunge Zhu, <yungez@microsoft.com>
# (c) 2017 Ansible Project
# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
from __future__ import (absolute_import, division, print_function)
__metaclass__ = type

DOCUMENTATION = """
---
name: azure_service_principal_attribute

requirements:
    - msgraph-sdk

author:
    - Yunge Zhu (@yungezz)

version_added: "1.12.0"

short_description: Look up Azure service principal attributes.

description:
  - Describes object id of your Azure service principal account.
options:
  azure_client_id:
    description: azure service principal client id.
  azure_secret:
    description: azure service principal secret
  azure_tenant:
    description: azure tenant
  azure_cloud_environment:
    description: azure cloud environment
"""

EXAMPLES = """
set_fact:
  object_id: "{{ lookup('azure_service_principal_attribute',
                         azure_client_id=azure_client_id,
                         azure_secret=azure_secret,
                         azure_tenant=azure_secret) }}"
"""

RETURN = """
_raw:
  description:
    Returns object id of service principal.
"""

from ansible.errors import AnsibleError
from ansible.plugins.lookup import LookupBase
from ansible.module_utils._text import to_native

try:
    from azure.cli.core import cloud as azure_cloud
    from azure.identity._credentials.client_secret import ClientSecretCredential
    import asyncio
    from msgraph import GraphServiceClient
    from msgraph.generated.service_principals.service_principals_request_builder import ServicePrincipalsRequestBuilder
except ImportError:
    pass


class LookupModule(LookupBase):
    def run(self, terms, variables, **kwargs):

        self.set_options(direct=kwargs)

        credentials = {}
        credentials['azure_client_id'] = self.get_option('azure_client_id', None)
        credentials['azure_secret'] = self.get_option('azure_secret', None)
        credentials['azure_tenant'] = self.get_option('azure_tenant', 'common')

        if credentials['azure_client_id'] is None or credentials['azure_secret'] is None:
            raise AnsibleError("Must specify azure_client_id and azure_secret")

        _cloud_environment = azure_cloud.AZURE_PUBLIC_CLOUD
        if self.get_option('azure_cloud_environment', None) is not None:
            _cloud_environment = azure_cloud.get_cloud_from_metadata_endpoint(credentials['azure_cloud_environment'])

        try:
            azure_credential_track2 = ClientSecretCredential(client_id=credentials['azure_client_id'],
                                                             client_secret=credentials['azure_secret'],
                                                             tenant_id=credentials['azure_tenant'],
                                                             authority=_cloud_environment.endpoints.active_directory)

            client = GraphServiceClient(azure_credential_track2)

            response = asyncio.get_event_loop().run_until_complete(self.get_service_principals(client, credentials['azure_client_id']))
            if not response:
                return []
            return list(response.value)[0].id.split(',')
        except Exception as ex:
            raise AnsibleError("Failed to get service principal object id: %s" % to_native(ex))
        return False

    async def get_service_principals(self, _client, app_id):
        request_configuration = ServicePrincipalsRequestBuilder.ServicePrincipalsRequestBuilderGetRequestConfiguration(
            query_parameters=ServicePrincipalsRequestBuilder.ServicePrincipalsRequestBuilderGetQueryParameters(
                filter="servicePrincipalNames/any(c:c eq '{0}')".format(app_id),
            )
        )
        return await _client.service_principals.get(request_configuration=request_configuration)
